@@ -1,5 +1,11 @@
 /* Default config.h for Hatari */
 
+/* Define to `__inline__' or `__inline' if that's what the C compiler
+   calls it, or to nothing if 'inline' is not supported under any name.  */
+#if defined(_MSC_VER)
+# define inline __inline
+#endif
+
 /* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'. */
 #define HAVE_DIRENT_H 1
 
@@ -13,21 +19,21 @@
 #define HAVE_ZLIB_H 1
 
 /* Define to 1 if you have the <termios.h> header file. */
-#if defined(WIN32)
+#if defined(WIN32) || defined(GEKKO)
 # undef  HAVE_TERMIOS_H
 #else
 # define HAVE_TERMIOS_H 1
 #endif
 
 /* Define to 1 if you have the <glob.h> header file. */
-#if defined(WIN32)
+#if defined(WIN32) || defined(GEKKO)
 # undef  HAVE_GLOB_H
 #else
 # define HAVE_GLOB_H 1
 #endif
 
 /* Define to 1 if you have the <strings.h> header file. */
-#if defined(__CEGCC__)
+#if defined(__CEGCC__) || defined(GEKKO)
 # undef  HAVE_STRINGS_H
 #else
 # define HAVE_STRINGS_H 1
@@ -41,7 +47,7 @@
 
 /* Define to 1 if you have the `cfmakeraw' function. */
 #if defined(__BEOS__) || (defined(__sun) && defined(__SVR4)) \
-    || defined(__CYGWIN__) \
+    || defined(__CYGWIN__)  || defined(GEKKO) \
     || defined(__AMIGAOS4__) || defined(__riscos) || defined(__CEGCC__)
 # undef  HAVE_CFMAKERAW
 #else
@@ -49,12 +55,19 @@
 #endif
 
 /* Define to 1 if you have the 'setenv' function. */
-#if defined(WIN32) || (defined(__sun) && defined(__SVR4))
+#if defined(WIN32) || (defined(__sun) && defined(__SVR4)) || defined(GEKKO)
 # undef HAVE_SETENV
 #else
 # define HAVE_SETENV 1
 #endif
 
+/* Define to 1 if you have the `select' function. */
+#if defined(GEKKO)
+# undef HAVE_SELECT
+#else
+# define HAVE_SELECT 1
+#endif
+
 /* Define to 1 if you have unix domain sockets */
 #if defined(WIN32) || defined(__CEGCC__)
 # undef  HAVE_UNIX_DOMAIN_SOCKETS
@@ -68,18 +81,25 @@
 #endif
 
 /* Define to 1 to use less memory - at the expense of emulation speed */
-#if defined(__CEGCC__)
+#if defined(__CEGCC__) || defined(GEKKO)
 # define ENABLE_SMALL_MEM 1
 #else
 # undef ENABLE_SMALL_MEM
 #endif
 
+/* Define to 1 to enable trace logs - undefine to slightly increase speed */
+#define ENABLE_TRACING 1
+
+/* Additional configuration for Visual-C */
+#if defined(_MSC_VER)
+# include "Visual.Studio/VisualStudioFix.h"
+#endif
+
 /* Define to the full name of this package. */
 #define PACKAGE_NAME "hatari"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "hatari CVS"
+#define PACKAGE_STRING "hatari devel"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "CVS"
-
+#define PACKAGE_VERSION "devel"
