@@ -17,18 +17,9 @@ const char Audio_fileid[] = "Hatari audio.c : " __DATE__ " " __TIME__;
 #include "sound.h"
 
 
-/* 11Khz, 22Khz, 44Khz playback */
-int const SoundPlayBackFrequencies[] =
-{
-	11025,  /* PLAYBACK_LOW */
-	22050,  /* PLAYBACK_MEDIUM */
-	44100,  /* PLAYBACK_HIGH */
-};
-
-
-bool bSoundWorking = FALSE;               /* Is sound OK */
-volatile bool bPlayingBuffer = FALSE;     /* Is playing buffer? */
-int OutputAudioFreqIndex = FREQ_22Khz;    /* Playback rate (11Khz,22Khz or 44Khz) */
+int nAudioFrequency = 44100;              /* Sound playback frequency */
+bool bSoundWorking = false;               /* Is sound OK */
+volatile bool bPlayingBuffer = false;     /* Is playing buffer? */
 int SoundBufferSize = 1024;               /* Size of sound buffer */
 int CompleteSndBufIdx;                    /* Replay-index into MixBuffer */
 
@@ -84,7 +75,7 @@ static void Audio_CallBack(void *userdata, Uint8 *stream, int len)
 
 /*-----------------------------------------------------------------------*/
 /**
- * Initialize the audio subsystem. Return TRUE if all OK.
+ * Initialize the audio subsystem. Return true if all OK.
  * We use direct access to the sound buffer, set to a unsigned 8-bit mono stream.
  */
 void Audio_Init(void)
@@ -96,7 +87,7 @@ void Audio_Init(void)
 	{
 		/* Stop any sound access */
 		Log_Printf(LOG_DEBUG, "Sound: Disabled\n");
-		bSoundWorking = FALSE;
+		bSoundWorking = false;
 		return;
 	}
 
@@ -106,13 +97,13 @@ void Audio_Init(void)
 		if (SDL_InitSubSystem(SDL_INIT_AUDIO) < 0)
 		{
 			fprintf(stderr, "Could not init audio: %s\n", SDL_GetError() );
-			bSoundWorking = FALSE;
+			bSoundWorking = false;
 			return;
 		}
 	}
 
 	/* Set up SDL audio: */
-	desiredAudioSpec.freq = SoundPlayBackFrequencies[OutputAudioFreqIndex];
+	desiredAudioSpec.freq = nAudioFrequency;
 	desiredAudioSpec.format = AUDIO_S16SYS;       /* 16-Bit signed */
 	desiredAudioSpec.channels = 2;                /* stereo */
 	desiredAudioSpec.samples = 1024;              /* Buffer size */
@@ -122,8 +113,8 @@ void Audio_Init(void)
 	if (SDL_OpenAudio(&desiredAudioSpec, NULL))   /* Open audio device */
 	{
 		fprintf(stderr, "Can't use audio: %s\n", SDL_GetError());
-		bSoundWorking = FALSE;
-		ConfigureParams.Sound.bEnableSound = FALSE;
+		bSoundWorking = false;
+		ConfigureParams.Sound.bEnableSound = false;
 		SDL_QuitSubSystem(SDL_INIT_AUDIO);
 		return;
 	}
@@ -135,9 +126,9 @@ void Audio_Init(void)
 	}
 
 	/* All OK */
-	bSoundWorking = TRUE;
+	bSoundWorking = true;
 	/* And begin */
-	Audio_EnableAudio(TRUE);
+	Audio_EnableAudio(true);
 }
 
 
@@ -150,11 +141,11 @@ void Audio_UnInit(void)
 	if (bSoundWorking)
 	{
 		/* Stop */
-		Audio_EnableAudio(FALSE);
+		Audio_EnableAudio(false);
 
 		SDL_CloseAudio();
 
-		bSoundWorking = FALSE;
+		bSoundWorking = false;
 	}
 }
 
@@ -183,13 +174,13 @@ void Audio_Unlock(void)
 /**
  * Set audio playback frequency variable, pass as PLAYBACK_xxxx
  */
-void Audio_SetOutputAudioFreq(int Frequency)
+void Audio_SetOutputAudioFreq(int nNewFrequency)
 {
 	/* Do not reset sound system if nothing has changed! */
-	if (Frequency != OutputAudioFreqIndex)
+	if (nNewFrequency != nAudioFrequency)
 	{
-		/* Set new frequency, index into SoundPlayBackFrequencies[] */
-		OutputAudioFreqIndex = Frequency;
+		/* Set new frequency */
+		nAudioFrequency = nNewFrequency;
 
 		/* Re-open SDL audio interface if necessary: */
 		if (bSoundWorking)
@@ -210,13 +201,13 @@ void Audio_EnableAudio(bool bEnable)
 	if (bEnable && !bPlayingBuffer)
 	{
 		/* Start playing */
-		SDL_PauseAudio(FALSE);
-		bPlayingBuffer = TRUE;
+		SDL_PauseAudio(false);
+		bPlayingBuffer = true;
 	}
 	else if (!bEnable && bPlayingBuffer)
 	{
 		/* Stop from playing */
-		SDL_PauseAudio(TRUE);
-		bPlayingBuffer = FALSE;
+		SDL_PauseAudio(true);
+		bPlayingBuffer = false;
 	}
 }
