@@ -39,7 +39,7 @@ static void ConvertLowRes_320x16Bit(void)
 			{
 				/* copy word */
 
-				bScreenContentsChanged = TRUE;
+				bScreenContentsChanged = true;
 
 #if SDL_BYTEORDER == SDL_BIG_ENDIAN
 				/* Plot pixels */
