@@ -40,14 +40,20 @@ const char DmaSnd_fileid[] = "Hatari dmaSnd.c : " __DATE__ " " __TIME__;
 #include "dmaSnd.h"
 #include "int.h"
 #include "ioMem.h"
+#include "log.h"
 #include "memorySnapShot.h"
 #include "mfp.h"
 #include "sound.h"
 #include "stMemory.h"
+#include "falcon/dsp.h"
+#include "falcon/dsp_core.h"
 
 
 Uint16 nDmaSoundControl;                /* Sound control register */
 
+static Sint16 DspOutBuffer[MIXBUFFER_SIZE*2];
+static int nDspOutRdPos, nDspOutWrPos, nDspBufSamples;
+
 static Uint16 nDmaSoundMode;            /* Sound mode register */
 static Uint16 nMicrowireData;           /* Microwire Data register */
 static Uint16 nMicrowireMask;           /* Microwire Mask register */
@@ -101,6 +107,8 @@ void DmaSnd_Reset(bool bCold)
 	}
 
 	nMwTransferSteps = 0;
+
+	nDspOutRdPos = nDspOutWrPos = 0;
 }
 
 
@@ -154,6 +162,13 @@ static void DmaSnd_StartNewFrame(void)
 	FrameCounter = 0;
 	nFrameLen = nFrameEndAddr - nFrameStartAddr;
 
+	if (nFrameLen <= 0)
+	{
+		Log_Printf(LOG_WARN, "DMA snd: Illegal buffer size (from 0x%x to 0x%x)\n",
+		          nFrameStartAddr, nFrameEndAddr);
+		return;
+	}
+
 	/* To get smooth sound, set an "interrupt" for the end of the frame that
 	 * updates the sound mix buffer. */
 	nCyclesForFrame = nFrameLen * (8013000.0 / DmaSnd_DetectSampleRate());
@@ -166,7 +181,7 @@ static void DmaSnd_StartNewFrame(void)
 /*-----------------------------------------------------------------------*/
 /**
  * Check if end-of-frame has been reached and raise interrupts if needed.
- * Returns TRUE if DMA sound processing should be stopped now and FALSE
+ * Returns true if DMA sound processing should be stopped now and false
  * if it continues.
  */
 static inline int DmaSnd_CheckForEndOfFrame(int nFrameCounter)
@@ -174,7 +189,7 @@ static inline int DmaSnd_CheckForEndOfFrame(int nFrameCounter)
 	if (nFrameCounter >= nFrameLen)
 	{
 		/* Raise end-of-frame interrupts (MFP-i7 and Time-A) */
-	    MFP_InputOnChannel(MFP_TIMER_GPIP7_BIT, MFP_IERA, &MFP_IPRA);
+		MFP_InputOnChannel(MFP_TIMER_GPIP7_BIT, MFP_IERA, &MFP_IPRA);
 		if (MFP_TACR == 0x08)       /* Is timer A in Event Count mode? */
 			MFP_TimerA_EventCount_Interrupt();
 
@@ -185,30 +200,78 @@ static inline int DmaSnd_CheckForEndOfFrame(int nFrameCounter)
 		else
 		{
 			nDmaSoundControl &= ~DMASNDCTRL_PLAY;
-			return TRUE;
+			return true;
 		}
 	}
 
-	return FALSE;
+	return false;
+}
+
+
+/**
+ * Mix DSP sound sample with the normal PSG sound samples.
+ */
+static void DmaSnd_GenerateDspSamples(int nMixBufIdx, int nSamplesToGenerate)
+{
+	double FreqRatio, fDspBufSamples, fDspBufRdPos;
+	int i;
+	int nBufIdx;
+
+	FreqRatio = DmaSnd_DetectSampleRate() / (double)nAudioFrequency;
+	FreqRatio *= 2.0;  /* Stereo */
+
+	fDspBufSamples = (double)nDspBufSamples;
+	fDspBufRdPos = (double)nDspOutRdPos;
+
+	for (i = 0; i < nSamplesToGenerate &&  fDspBufSamples > 0.0; i++)
+	{
+		nBufIdx = (nMixBufIdx + i) % MIXBUFFER_SIZE;
+		nDspOutRdPos = (((int)fDspBufRdPos) & -2) % (MIXBUFFER_SIZE*2);
+
+		MixBuffer[nBufIdx][0] = ((int)MixBuffer[nBufIdx][0]
+		                        + (int)(DspOutBuffer[nDspOutRdPos+0])) / 2;
+		MixBuffer[nBufIdx][1] = ((int)MixBuffer[nBufIdx][1]
+		                        + (int)(DspOutBuffer[nDspOutRdPos+1])) / 2;
+
+		fDspBufRdPos += FreqRatio;
+		fDspBufSamples -= FreqRatio;
+	}
+
+	if (fDspBufSamples > 0.0)
+		nDspBufSamples = (int)fDspBufSamples;
+	else
+		nDspBufSamples = 0;
 }
 
 
 /*-----------------------------------------------------------------------*/
 /**
  * Mix DMA sound sample with the normal PSG sound samples.
+ * Note: We adjust the volume level of the 8-bit DMA samples to factor
+ * 0.5 compared to the PSG sound samples, this seems to be quite similar
+ * to a real STE (and since we got to divide it by 2 again for adding them
+ * to the YM samples and multiply by 256 to get to 16-bit, we simply multiply
+ * them by 64 in total).
  */
 void DmaSnd_GenerateSamples(int nMixBufIdx, int nSamplesToGenerate)
 {
 	double FreqRatio;
 	int i;
-	int nBufIdx;
+	int nBufIdx, nFramePos;
 	Sint8 *pFrameStart;
 
+	if (ConfigureParams.System.nMachineType == MACHINE_FALCON
+	    && (IoMem_ReadWord(0xff8932) & 0x6000) == 0x2000)
+	{
+		DmaSnd_GenerateDspSamples(nMixBufIdx, nSamplesToGenerate);
+		return;
+	}
+
 	if (!(nDmaSoundControl & DMASNDCTRL_PLAY))
 		return;
 
 	pFrameStart = (Sint8 *)&STRam[nFrameStartAddr];
-	FreqRatio = DmaSnd_DetectSampleRate() / (double)SoundPlayBackFrequencies[OutputAudioFreqIndex];
+	FreqRatio = DmaSnd_DetectSampleRate() / (double)nAudioFrequency;
 
 	if (ConfigureParams.System.nMachineType == MACHINE_FALCON
 	    && (nDmaSoundMode & DMASNDMODE_16BITSTEREO))
@@ -218,10 +281,11 @@ void DmaSnd_GenerateSamples(int nMixBufIdx, int nSamplesToGenerate)
 		for (i = 0; i < nSamplesToGenerate; i++)
 		{
 			nBufIdx = (nMixBufIdx + i) % MIXBUFFER_SIZE;
-			MixBuffer[nBufIdx][0] = ((int)MixBuffer[nBufIdx][0]
-			                        + (int)(*(Sint16*)&pFrameStart[((int)FrameCounter)&~1])) / 2;
-			MixBuffer[nBufIdx][1] = ((int)MixBuffer[nBufIdx][1]
-			                        + (int)(*(Sint16*)&pFrameStart[(((int)FrameCounter)&~1)+2])) / 2;
+			nFramePos = ((int)FrameCounter) & ~3;
+			MixBuffer[nBufIdx][0] = (int)MixBuffer[nBufIdx][0]
+				+ ((int)(Sint16)do_get_mem_word(&pFrameStart[nFramePos]))/2;
+			MixBuffer[nBufIdx][1] = (int)MixBuffer[nBufIdx][1]
+				+ ((int)(Sint16)do_get_mem_word(&pFrameStart[nFramePos+2]))/2;
 			FrameCounter += FreqRatio;
 			if (DmaSnd_CheckForEndOfFrame(FrameCounter))
 				break;
@@ -234,7 +298,8 @@ void DmaSnd_GenerateSamples(int nMixBufIdx, int nSamplesToGenerate)
 		{
 			nBufIdx = (nMixBufIdx + i) % MIXBUFFER_SIZE;
 			MixBuffer[nBufIdx][0] = MixBuffer[nBufIdx][1] =
-				((int)MixBuffer[nBufIdx][0] + (((int)pFrameStart[(int)FrameCounter]) << 8)) / 2;
+				(int)MixBuffer[nBufIdx][0]
+				+ 64 * (int)pFrameStart[(int)FrameCounter];
 			FrameCounter += FreqRatio;
 			if (DmaSnd_CheckForEndOfFrame(FrameCounter))
 				break;
@@ -247,10 +312,11 @@ void DmaSnd_GenerateSamples(int nMixBufIdx, int nSamplesToGenerate)
 		for (i = 0; i < nSamplesToGenerate; i++)
 		{
 			nBufIdx = (nMixBufIdx + i) % MIXBUFFER_SIZE;
-			MixBuffer[nBufIdx][0] = ((int)MixBuffer[nBufIdx][0]
-			                        + (((int)pFrameStart[((int)FrameCounter)&~1]) << 8)) / 2;
-			MixBuffer[nBufIdx][1] = ((int)MixBuffer[nBufIdx][1]
-			                        + (((int)pFrameStart[(((int)FrameCounter)&~1)+1]) << 8)) / 2;
+			nFramePos = ((int)FrameCounter) & ~1;
+			MixBuffer[nBufIdx][0] = (int)MixBuffer[nBufIdx][0]
+			                        + 64 * (int)pFrameStart[nFramePos];
+			MixBuffer[nBufIdx][1] = (int)MixBuffer[nBufIdx][1]
+			                        + 64 * (int)pFrameStart[nFramePos+1];
 			FrameCounter += FreqRatio;
 			if (DmaSnd_CheckForEndOfFrame(FrameCounter))
 				break;
@@ -300,6 +366,8 @@ static Uint32 DmaSnd_GetFrameCount(void)
 void DmaSnd_SoundControl_ReadWord(void)
 {
 	IoMem_WriteWord(0xff8900, nDmaSoundControl);
+
+	LOG_TRACE(TRACE_DMASND, "DMA snd control write: 0x%04x\n", nDmaSoundControl);
 }
 
 
@@ -313,6 +381,8 @@ void DmaSnd_SoundControl_WriteWord(void)
 {
 	Uint16 nNewSndCtrl;
 
+	LOG_TRACE(TRACE_DMASND, "DMA snd control write: 0x%04x\n", IoMem_ReadWord(0xff8900));
+
 	nNewSndCtrl = IoMem_ReadWord(0xff8900) & 3;
 
 	if (!(nDmaSoundControl & DMASNDCTRL_PLAY) && (nNewSndCtrl & DMASNDCTRL_PLAY))
@@ -366,22 +436,22 @@ void DmaSnd_FrameCountLow_ReadByte(void)
 void DmaSnd_SoundMode_ReadWord(void)
 {
 	IoMem_WriteWord(0xff8920, nDmaSoundMode);
+
+	LOG_TRACE(TRACE_DMASND, "DMA snd mode read: 0x%04x\n", nDmaSoundMode);
 }
 
 
 /*-----------------------------------------------------------------------*/
 /**
  * Write word to sound mode register (0xff8920).
- * Handling framework for Falcon specific bits by Matthias Arndt <marndt@asmsoftware.de>
  */
 void DmaSnd_SoundMode_WriteWord(void)
 {
-	/* Handle Falcon specialities: STE and TT only have bits 7,1 and 0 in this register */
+	LOG_TRACE(TRACE_DMASND, "DMA snd mode write: 0x%04x\n", IoMem_ReadWord(0xff8920));
 
 	/* Falcon has meaning in almost all bits of SND_SMC */
 	if (ConfigureParams.System.nMachineType == MACHINE_FALCON)
 	{
-
 		nDmaSoundMode = IoMem_ReadWord(0xff8920);
 		/* FIXME: add code here to evaluate Falcon specific settings */
 
@@ -394,11 +464,11 @@ void DmaSnd_SoundMode_WriteWord(void)
 		/* we also write the masked value back into the emulated hw registers so we have a correct value there */
 		IoMem_WriteWord(0xff8920,nDmaSoundMode);
 	}
-	//fprintf(stderr,"New sound mode = $%x\n", nDmaSoundMode);
 }
 
 
-/*-----------------------------------------------------------------------*/
+/* ---------------------- Microwire / LMC 1992  ---------------------- */
+
 /**
  * Handle the shifting/rotating of the microwire registers
  * The microwire regs should be done after 16 usec = 32 NOPs = 128 cycles.
@@ -442,7 +512,7 @@ void DmaSnd_InterruptHandler_Microwire(void)
 void DmaSnd_MicrowireData_ReadWord(void)
 {
 	/* Shifting is done in DmaSnd_InterruptHandler_Microwire! */
-	//fprintf(stderr, "MW data read: 0x%x\n", IoMem_ReadWord(0xff8922));
+	LOG_TRACE(TRACE_DMASND, "Microwire data read: 0x%x\n", IoMem_ReadWord(0xff8922));
 }
 
 
@@ -460,7 +530,7 @@ void DmaSnd_MicrowireData_WriteWord(void)
 		Int_AddRelativeInterrupt(8, INT_CPU_CYCLE, INTERRUPT_DMASOUND_MICROWIRE);
 	}
 
-	//fprintf(stderr, "MW data write: 0x%x\n", IoMem_ReadWord(0xff8922));
+	LOG_TRACE(TRACE_DMASND, "Microwire data write: 0x%x\n", IoMem_ReadWord(0xff8922));
 }
 
 
@@ -470,7 +540,7 @@ void DmaSnd_MicrowireData_WriteWord(void)
 void DmaSnd_MicrowireMask_ReadWord(void)
 {
 	/* Same as with data register, but mask is rotated, not shifted. */
-	//fprintf(stderr, "MW mask read: 0x%x\n", IoMem_ReadWord(0xff8924));
+	LOG_TRACE(TRACE_DMASND,  "Microwire mask read: 0x%x\n", IoMem_ReadWord(0xff8924));
 }
 
 
@@ -485,5 +555,219 @@ void DmaSnd_MicrowireMask_WriteWord(void)
 		nMicrowireMask = IoMem_ReadWord(0xff8924);
 	}
 
-	//fprintf(stderr, "MW mask write: 0x%x\n", IoMem_ReadWord(0xff8924));
+	LOG_TRACE(TRACE_DMASND, "Microwire mask write: 0x%x\n", IoMem_ReadWord(0xff8924));
+}
+
+
+/* ---------------------- Falcon sound subsystem ---------------------- */
+
+
+static void DmaSnd_StartDspXmitHandler(void)
+{
+	Uint16 nCbSrc = IoMem_ReadWord(0xff8930);
+	int nFreq;
+	int nClkDiv;
+
+	/* Ignore when DSP XMIT is connected to external port */
+	if ((nCbSrc & 0x80) == 0x00)
+		return;
+
+	nClkDiv = 256 * ((IoMem_ReadByte(0xff8935) & 0x0f) + 1);
+
+	if ((nCbSrc & 0x60) == 0x00)
+	{
+		/* Internal 25.175 MHz clock */
+		nFreq = 25175000 / nClkDiv;
+		Int_AddRelativeInterrupt((8013000+nFreq/2)/nFreq/2, INT_CPU_CYCLE, INTERRUPT_DSPXMIT);
+	}
+	else if ((nCbSrc & 0x60) == 0x20)
+	{
+		/* Internal 32 MHz clock */
+		nFreq = 32000000 / nClkDiv;
+		Int_AddRelativeInterrupt((8013000+nFreq/2)/nFreq/2, INT_CPU_CYCLE, INTERRUPT_DSPXMIT);
+	}
+
+	/* Put last sample into buffer */
+	DspOutBuffer[nDspOutWrPos] = DSP_SsiReadTxValue();
+
+	nDspOutWrPos = (nDspOutWrPos + 1) % (MIXBUFFER_SIZE*2);
+	nDspBufSamples += 1;
+}
+
+
+void DmaSnd_InterruptHandler_DspXmit(void)
+{
+	/* Remove this interrupt from list and re-order */
+	Int_AcknowledgeInterrupt();
+
+	/* TODO: Trigger SSI transmit interrupt in the DSP and fetch the data,
+	 *       then distribute the data to the destinations */
+
+	DSP_SsiReceive_SC2(FrameCounter);
+	DSP_SsiReceiveSerialClock();
+
+	/* Restart the Int event handler */
+	DmaSnd_StartDspXmitHandler();
+
+}
+
+
+/**
+ * Read word from Falcon crossbar source register (0xff8930).
+ */
+void DmaSnd_CrossbarSrc_ReadWord(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd crossbar src read: 0x%04x\n", IoMem_ReadWord(0xff8930));
+}
+
+/**
+ * Write word to Falcon crossbar source register (0xff8930).
+ */
+void DmaSnd_CrossbarSrc_WriteWord(void)
+{
+	Uint16 nCbSrc = IoMem_ReadWord(0xff8930);
+
+	LOG_TRACE(TRACE_DMASND, "Falcon snd crossbar src write: 0x%04x\n", nCbSrc);
+
+	DmaSnd_StartDspXmitHandler();
+}
+
+/**
+ * Read word from Falcon crossbar destination register (0xff8932).
+ */
+void DmaSnd_CrossbarDst_ReadWord(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd crossbar dst read: 0x%04x\n", IoMem_ReadWord(0xff8932));
+}
+
+/**
+ * Write word to Falcon crossbar destination register (0xff8932).
+ */
+void DmaSnd_CrossbarDst_WriteWord(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd crossbar dst write: 0x%04x\n", IoMem_ReadWord(0xff8932));
+}
+
+/**
+ * Read byte from external clock divider register (0xff8934).
+ */
+void DmaSnd_FreqDivExt_ReadByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd ext. clock divider read: 0x%02x\n", IoMem_ReadByte(0xff8934));
+}
+
+/**
+ * Write byte to external clock divider register (0xff8934).
+ */
+void DmaSnd_FreqDivExt_WriteByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd ext. clock divider write: 0x%02x\n", IoMem_ReadByte(0xff8934));
+}
+
+/**
+ * Write byte to internal clock divider register (0xff8935).
+ */
+void DmaSnd_FreqDivInt_ReadByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd int. clock divider read: 0x%02x\n", IoMem_ReadByte(0xff8935));
+}
+
+/**
+ * Write byte to internal clock divider register (0xff8935).
+ */
+void DmaSnd_FreqDivInt_WriteByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd int. clock divider write: 0x%02x\n", IoMem_ReadByte(0xff8935));
+}
+
+/**
+ * Read byte from track record control register (0xff8936).
+ */
+void DmaSnd_TrackRecCtrl_ReadByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd track record control read: 0x%02x\n", IoMem_ReadByte(0xff8936));
+}
+
+/**
+ * Write byte to track record control register (0xff8936).
+ */
+void DmaSnd_TrackRecCtrl_WriteByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd track record control write: 0x%02x\n", IoMem_ReadByte(0xff8936));
+}
+
+/**
+ * Read byte from CODEC input register (0xff8937).
+ */
+void DmaSnd_CodecInput_ReadByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd CODEC input read: 0x%02x\n", IoMem_ReadByte(0xff8937));
+}
+
+/**
+ * Write byte to CODEC input register (0xff8937).
+ */
+void DmaSnd_CodecInput_WriteByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd CODEC input write: 0x%02x\n", IoMem_ReadByte(0xff8937));
+}
+
+/**
+ * Read byte from A/D converter input register (0xff8938).
+ */
+void DmaSnd_AdcInput_ReadByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd ADC input read: 0x%02x\n", IoMem_ReadByte(0xff8938));
+}
+
+/**
+ * Write byte to A/D converter input register (0xff8938).
+ */
+void DmaSnd_AdcInput_WriteByte(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd ADC input write: 0x%02x\n", IoMem_ReadByte(0xff8938));
+}
+
+/**
+ * Read byte from input amplifier register (0xff8939).
+ */
+void DmaSnd_InputAmp_ReadByte(void)
+{
+}
+
+/**
+ * Write byte to input amplifier register (0xff8939).
+ */
+void DmaSnd_InputAmp_WriteByte(void)
+{
+}
+
+/**
+ * Read word from output reduction register (0xff893a).
+ */
+void DmaSnd_OutputReduct_ReadWord(void)
+{
+}
+
+/**
+ * Write word to output reduction register (0xff893a).
+ */
+void DmaSnd_OutputReduct_WriteWord(void)
+{
+}
+
+/**
+ * Read word from CODEC status register (0xff893c).
+ */
+void DmaSnd_CodecStatus_ReadWord(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd CODEC status read: 0x%04x\n", IoMem_ReadWord(0xff893c));
+}
+
+/**
+ * Write word to CODEC status register (0xff893c).
+ */
+void DmaSnd_CodecStatus_WriteWord(void)
+{
+	LOG_TRACE(TRACE_DMASND, "Falcon snd CODEC status write: 0x%04x\n", IoMem_ReadWord(0xff893c));
 }
