@@ -207,8 +207,8 @@ void FDC_Reset(void)
 	FDCEmulationRunning = FDCEMU_RUN_NULL;        /* Running command under above */
 
 	FDCStepDirection = 1;                         /* +Track on 'Step' command */
-	bDMAWaiting = FALSE;                          /* No DMA waiting */
-	bMotorOn = FALSE;                             /* Motor off */
+	bDMAWaiting = false;                          /* No DMA waiting */
+	bMotorOn = false;                             /* Motor off */
 	MotorSlowingCount = 0;                        /* Counter for motor slowing down before stopping */
 }
 
@@ -251,7 +251,7 @@ void FDC_MemorySnapShot_Capture(bool bSave)
  */
 static void FDC_TurnMotorOn(void)
 {
-	bMotorOn = TRUE;                  /* Turn motor on */
+	bMotorOn = true;                  /* Turn motor on */
 	MotorSlowingCount = 0;
 }
 
@@ -278,7 +278,7 @@ static void FDC_UpdateMotor(void)
 		MotorSlowingCount--;
 
 		if (MotorSlowingCount==0)
-			bMotorOn = FALSE;         /* Motor finally stopped */
+			bMotorOn = false;         /* Motor finally stopped */
 	}
 }
 
@@ -294,7 +294,7 @@ void FDC_ResetDMAStatus(void)
 	DMAStatus_ff8606rd = 0;           /* Clear out */
 
 	FDCSectorCountRegister = 0;
-	FDC_SetDMAStatus(FALSE);          /* Set no error */
+	FDC_SetDMAStatus(false);          /* Set no error */
 
 	/* Reset HDC command status */
 	HDCSectorCount = 0;
@@ -446,7 +446,7 @@ void FDC_GpipRead(void)
 
 	if ((MFP_GPIP & 0x20) == nLastGpipBit)
 	{
-		if (!ConfigureParams.System.bSlowFDC)
+		if (!ConfigureParams.DiskImage.bSlowFloppy)
 		{
 			/* Restart FDC update interrupt to occur right after a few cycles */
 			Int_RemovePendingInterrupt(INTERRUPT_FDC);
@@ -478,7 +478,7 @@ void FDC_InterruptHandler_Update(void)
 		/* Yes, copy it */
 		FDC_DMADataFromFloppy();
 		/* Signal done */
-		bDMAWaiting = FALSE;
+		bDMAWaiting = false;
 	}
 
 	/* Update drive motor */
@@ -554,7 +554,7 @@ void FDC_UpdateRestoreCmd(void)
 		/* Acknowledge interrupt, move along there's nothing more to see */
 		FDC_AcknowledgeInterrupt();
 		/* Set error */
-		FDC_SetDMAStatus(FALSE);          /* No DMA error */
+		FDC_SetDMAStatus(false);          /* No DMA error */
 		/* Done */
 		FDCEmulationCommand = FDCEMU_CMD_NULL;
 		/* Turn motor off */
@@ -590,7 +590,7 @@ void FDC_UpdateSeekCmd(void)
 		/* Acknowledge interrupt, move along there's nothing more to see */
 		FDC_AcknowledgeInterrupt();
 		/* Set error */
-		FDC_SetDMAStatus(FALSE);          /* No DMA error */
+		FDC_SetDMAStatus(false);          /* No DMA error */
 		/* Done */
 		FDCEmulationCommand = FDCEMU_CMD_NULL;
 		/* Turn motor off */
@@ -621,7 +621,7 @@ void FDC_UpdateStepCmd(void)
 		/* Acknowledge interrupt, move along there's nothing more to see */
 		FDC_AcknowledgeInterrupt();
 		/* Set error */
-		FDC_SetDMAStatus(FALSE);            /* No DMA error */
+		FDC_SetDMAStatus(false);            /* No DMA error */
 		/* Done */
 		FDCEmulationCommand = FDCEMU_CMD_NULL;
 		/* Turn motor off */
@@ -649,7 +649,7 @@ void FDC_UpdateStepInCmd(void)
 		/* Acknowledge interrupt, move along there's nothing more to see */
 		FDC_AcknowledgeInterrupt();
 		/* Set error */
-		FDC_SetDMAStatus(FALSE);            /* No DMA error */
+		FDC_SetDMAStatus(false);            /* No DMA error */
 		/* Done */
 		FDCEmulationCommand = FDCEMU_CMD_NULL;
 		/* Turn motor off */
@@ -679,7 +679,7 @@ void FDC_UpdateStepOutCmd(void)
 		/* Acknowledge interrupt, move along there's nothing more to see */
 		FDC_AcknowledgeInterrupt();
 		/* Set error */
-		FDC_SetDMAStatus(FALSE);            /* No DMA error */
+		FDC_SetDMAStatus(false);            /* No DMA error */
 		/* Done */
 		FDCEmulationCommand = FDCEMU_CMD_NULL;
 		/* Turn motor off */
@@ -711,14 +711,14 @@ void FDC_UpdateReadSectorsCmd(void)
 			if (nReadWriteSectors<=0)
 				FDCEmulationRunning = FDCEMU_RUN_READSECTORS_COMPLETE;
 
-			bDMAWaiting = TRUE;
+			bDMAWaiting = true;
 		}
 		else
 		{
 			/* Acknowledge interrupt, move along there's nothing more to see */
 			FDC_AcknowledgeInterrupt();
 			/* Set error */
-			FDC_SetDMAStatus(TRUE);             /* DMA error */
+			FDC_SetDMAStatus(true);             /* DMA error */
 			/* Done */
 			FDCEmulationCommand = FDCEMU_CMD_NULL;
 			/* Turn motor off */
@@ -729,7 +729,7 @@ void FDC_UpdateReadSectorsCmd(void)
 		/* Acknowledge interrupt, move along there's nothing more to see */
 		FDC_AcknowledgeInterrupt();
 		/* Set error */
-		FDC_SetDMAStatus(FALSE);              /* No DMA error */
+		FDC_SetDMAStatus(false);              /* No DMA error */
 		/* Done */
 		FDCEmulationCommand = FDCEMU_CMD_NULL;
 		/* Turn motor off */
@@ -770,7 +770,7 @@ void FDC_UpdateWriteSectorsCmd(void)
 			/* Acknowledge interrupt, move along there's nothing more to see */
 			FDC_AcknowledgeInterrupt();
 			/* Set error */
-			FDC_SetDMAStatus(TRUE);             /* DMA error */
+			FDC_SetDMAStatus(true);             /* DMA error */
 			/* Done */
 			FDCEmulationCommand = FDCEMU_CMD_NULL;
 			/* Turn motor off */
@@ -781,7 +781,7 @@ void FDC_UpdateWriteSectorsCmd(void)
 		/* Acknowledge interrupt, move along there's nothing more to see */
 		FDC_AcknowledgeInterrupt();
 		/* Set error */
-		FDC_SetDMAStatus(FALSE);              /* No DMA error */
+		FDC_SetDMAStatus(false);              /* No DMA error */
 		/* Done */
 		FDCEmulationCommand = FDCEMU_CMD_NULL;
 		/* Turn motor off */
@@ -808,7 +808,7 @@ void FDC_UpdateReadAddressCmd(void)
 		/* Acknowledge interrupt, move along there's nothing more to see */
 		FDC_AcknowledgeInterrupt();
 		/* Set error */
-		FDC_SetDMAStatus(FALSE);            /* No DMA error */
+		FDC_SetDMAStatus(false);            /* No DMA error */
 		/* Done */
 		FDCEmulationCommand = FDCEMU_CMD_NULL;
 		/* Turn motor off */
@@ -829,8 +829,12 @@ void FDC_UpdateReadAddressCmd(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeI_Restore(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type I restore VBL=%d video_cyc=%d pc=%x\n" ,
-		nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type I restore VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to seek to track zero */
 	FDCEmulationCommand = FDCEMU_CMD_RESTORE;
@@ -843,8 +847,12 @@ static void FDC_TypeI_Restore(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeI_Seek(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type I seek track=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		FDCDataRegister , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type I seek track=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  FDCDataRegister, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to seek to chosen track */
 	FDCEmulationCommand = FDCEMU_CMD_SEEK;
@@ -857,8 +865,12 @@ static void FDC_TypeI_Seek(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeI_Step(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type I step %d VBL=%d video_cyc=%d pc=%x\n" ,
-		FDCStepDirection , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type I step %d VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  FDCStepDirection, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to step(same direction as last seek executed, eg 'FDCStepDirection') */
 	FDCEmulationCommand = FDCEMU_CMD_STEP;
@@ -871,8 +883,12 @@ static void FDC_TypeI_Step(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeI_StepIn(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type I step in VBL=%d video_cyc=%d pc=%x\n" ,
-		nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type I step in VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to step in(Set 'FDCStepDirection') */
 	FDCEmulationCommand = FDCEMU_CMD_STEPIN;
@@ -886,8 +902,12 @@ static void FDC_TypeI_StepIn(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeI_StepOut(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type I step out VBL=%d video_cyc=%d pc=%x\n" ,
-		nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type I step out VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to step out(Set 'FDCStepDirection') */
 	FDCEmulationCommand = FDCEMU_CMD_STEPOUT;
@@ -909,8 +929,12 @@ static void FDC_TypeI_StepOut(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeII_ReadSector(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type II read sector %d VBL=%d video_cyc=%d pc=%x\n" ,
-		FDCSectorRegister , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type II read sector %d VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  FDCSectorRegister, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to read a single sector */
 	FDCEmulationCommand = FDCEMU_CMD_READSECTORS;
@@ -925,8 +949,13 @@ static void FDC_TypeII_ReadSector(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeII_ReadMultipleSectors(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type II read multi sectors %d count %d VBL=%d video_cyc=%d pc=%x\n" ,
-		FDCSectorRegister , FDCSectorCountRegister , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type II read multi sectors %d count %d VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  FDCSectorRegister, FDCSectorCountRegister, nVBLs,
+		  FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to read sectors */
 	FDCEmulationCommand = FDCEMU_CMD_READMULTIPLESECTORS;
@@ -941,8 +970,12 @@ static void FDC_TypeII_ReadMultipleSectors(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeII_WriteSector(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type II write sector %d VBL=%d video_cyc=%d pc=%x\n" ,
-		FDCSectorRegister , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type II write sector %d VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  FDCSectorRegister, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to write a single sector */
 	FDCEmulationCommand = FDCEMU_CMD_WRITESECTORS;
@@ -957,8 +990,12 @@ static void FDC_TypeII_WriteSector(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeII_WriteMultipleSectors(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type II write multi sectors %d count %d VBL=%d video_cyc=%d pc=%x\n" ,
-		FDCSectorRegister , FDCSectorCountRegister , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type II write multi sectors %d count %d VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  FDCSectorRegister, FDCSectorCountRegister, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Set emulation to write sectors */
 	FDCEmulationCommand = FDCEMU_CMD_WRITEMULTIPLESECTORS;
@@ -981,8 +1018,12 @@ static void FDC_TypeII_WriteMultipleSectors(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeIII_ReadAddress(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type III read address unimplemented VBL=%d video_cyc=%d pc=%x\n" ,
-		nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type III read address unimplemented VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	Log_Printf(LOG_TODO, "FDC type III command 'read address' is not implemented yet!\n");
 
@@ -997,8 +1038,12 @@ static void FDC_TypeIII_ReadAddress(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeIII_ReadTrack(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type III read track 0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		FDCTrackRegister , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type III read track 0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  FDCTrackRegister, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	Log_Printf(LOG_TODO, "FDC type III command 'read track' does not work yet!\n");
 
@@ -1017,8 +1062,12 @@ static void FDC_TypeIII_ReadTrack(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeIII_WriteTrack(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type III write track 0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		FDCTrackRegister , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type III write track 0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  FDCTrackRegister, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	Log_Printf(LOG_TODO, "FDC type III command 'write track' does not work yet!\n");
 
@@ -1045,8 +1094,12 @@ static void FDC_TypeIII_WriteTrack(void)
 /*-----------------------------------------------------------------------*/
 static void FDC_TypeIV_ForceInterrupt(bool bCauseCPUInterrupt)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc type IV force int VBL=%d video_cyc=%d pc=%x\n" ,
-		nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc type IV force int VBL=%d video_cyc=%d %d@%dpc=%x\n",
+		  nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	/* Acknowledge interrupt, move along there's nothing more to see */
 	if (bCauseCPUInterrupt)
@@ -1162,9 +1215,9 @@ static void FDC_ExecuteTypeIVCommands(void)
 
 	/* Check Type IV Command */
 	if ((FDCCommandRegister&0x0c) == 0)     /* I3 and I2 are clear? If so we don't need a CPU interrupt */
-		FDC_TypeIV_ForceInterrupt(FALSE);   /* Force Interrupt - no interrupt */
+		FDC_TypeIV_ForceInterrupt(false);   /* Force Interrupt - no interrupt */
 	else
-		FDC_TypeIV_ForceInterrupt(TRUE);    /* Force Interrupt */
+		FDC_TypeIV_ForceInterrupt(true);    /* Force Interrupt */
 }
 
 
@@ -1194,8 +1247,12 @@ static void FDC_ExecuteCommand(void)
  */
 static void FDC_WriteSectorCountRegister(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write 8604 sector count=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		DiskControllerWord_ff8604wr , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc write 8604 sector count=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  DiskControllerWord_ff8604wr, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	FDCSectorCountRegister = DiskControllerWord_ff8604wr;
 }
@@ -1207,8 +1264,12 @@ static void FDC_WriteSectorCountRegister(void)
  */
 static void FDC_WriteCommandRegister(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write 8604 command=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		DiskControllerWord_ff8604wr , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc write 8604 command=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n",
+		  DiskControllerWord_ff8604wr, nVBLs, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC());
 
 	FDCCommandRegister = DiskControllerWord_ff8604wr;
 	/* And execute */
@@ -1222,8 +1283,12 @@ static void FDC_WriteCommandRegister(void)
  */
 static void FDC_WriteTrackRegister(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write 8604 track=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		DiskControllerWord_ff8604wr , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc write 8604 track=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		DiskControllerWord_ff8604wr , nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 
 	FDCTrackRegister = DiskControllerWord_ff8604wr & 0xff;	/* 0...79 */
 }
@@ -1235,8 +1300,12 @@ static void FDC_WriteTrackRegister(void)
  */
 static void FDC_WriteSectorRegister(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write 8604 sector=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		DiskControllerWord_ff8604wr , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc write 8604 sector=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		DiskControllerWord_ff8604wr , nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 
 	FDCSectorRegister = DiskControllerWord_ff8604wr & 0xff;	/* 1,2,3..... */
 }
@@ -1248,8 +1317,12 @@ static void FDC_WriteSectorRegister(void)
  */
 static void FDC_WriteDataRegister(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write 8604 data=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		DiskControllerWord_ff8604wr , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc write 8604 data=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		DiskControllerWord_ff8604wr , nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 
 	FDCDataRegister = DiskControllerWord_ff8604wr & 0xff;
 }
@@ -1261,6 +1334,8 @@ static void FDC_WriteDataRegister(void)
  */
 void FDC_DiskController_WriteWord(void)
 {
+	int FrameCycles, HblCounterVideo, LineCycles;
+
 	if (nIoMemAccessSize == SIZE_BYTE)
 	{
 		/* This register does not like to be accessed in byte mode on a normal ST */
@@ -1272,14 +1347,18 @@ void FDC_DiskController_WriteWord(void)
 
 	DiskControllerWord_ff8604wr = IoMem_ReadWord(0xff8604);
 
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write 8604 data=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		DiskControllerWord_ff8604wr , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
 
-	HDC_WriteCommandPacket();                 /*  Handle HDC functions */
+	LOG_TRACE(TRACE_FDC, "fdc write 8604 data=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		DiskControllerWord_ff8604wr , nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 
-	/* filter hdc commands */
+	/* Is it an ASCII HD command? */
 	if ((DMAModeControl_ff8606wr & 0x0018) == 8)
+	{
+		/*  Handle HDC functions */
+		HDC_WriteCommandPacket();
 		return;
+	}
 
 	/* Are we trying to set the SectorCount? */
 	if (DMAModeControl_ff8606wr&0x10)         /* Bit 4 */
@@ -1314,6 +1393,8 @@ void FDC_DiskController_WriteWord(void)
 void FDC_DiskControllerStatus_ReadWord(void)
 {
 	Sint16 DiskControllerByte = 0;            /* Used to pass back the parameter */
+	int FrameCycles, HblCounterVideo, LineCycles;
+
 
 	if (nIoMemAccessSize == SIZE_BYTE)
 	{
@@ -1354,7 +1435,7 @@ void FDC_DiskControllerStatus_ReadWord(void)
 				 * exchange disks on a real ST). We now also simulate this behaviour
 				 * here, so that these games can continue with the other disk. */
 				DiskControllerByte ^= 0x40;
-				EmulationDrives[nReadWriteDev].bMediaChanged = FALSE;
+				EmulationDrives[nReadWriteDev].bMediaChanged = false;
 			}
 
 			/* Reset FDC GPIP */
@@ -1374,8 +1455,10 @@ void FDC_DiskControllerStatus_ReadWord(void)
 
 	IoMem_WriteWord(0xff8604, DiskControllerByte);
 
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc read 8604 ctrl status=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		DiskControllerByte , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc read 8604 ctrl status=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		DiskControllerByte , nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 }
 
 
@@ -1400,8 +1483,12 @@ Uint32 FDC_ReadDMAAddress(void)
  */
 void FDC_WriteDMAAddress(Uint32 Address)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write 0x%x to dma address VBL=%d video_cyc=%d pc=%x\n" ,
-		Address , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc write 0x%x to dma address VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		Address , nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 
 	/* Store as 24-bit address */
 	STMemory_WriteByte(0xff8609, Address>>16);
@@ -1417,8 +1504,13 @@ void FDC_WriteDMAAddress(Uint32 Address)
  */
 bool FDC_ReadSectorFromFloppy(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc read sector addr=0x%x dev=%d sect=%d track=%d side=%d VBL=%d video_cyc=%d pc=%x\n" ,
-		FDC_ReadDMAAddress(), nReadWriteDev, nReadWriteSector, nReadWriteTrack, nReadWriteSide, nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	int FrameCycles, HblCounterVideo, LineCycles;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc read sector addr=0x%x dev=%d sect=%d track=%d side=%d VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		FDC_ReadDMAAddress(), nReadWriteDev, nReadWriteSector, nReadWriteTrack, nReadWriteSide,
+		nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 
 	/* Copy in 1 sector to our workspace */
 	if (Floppy_ReadSectors(nReadWriteDev, DMASectorWorkSpace, nReadWriteSector, nReadWriteTrack, nReadWriteSide, 1, NULL))
@@ -1430,12 +1522,12 @@ bool FDC_ReadSectorFromFloppy(void)
 			nReadWriteSector = 1;
 			nReadWriteTrack++;
 		}
-		return TRUE;
+		return true;
 	}
 
 	/* Failed */
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc read sector failed\n" );
-	return FALSE;
+	LOG_TRACE(TRACE_FDC, "fdc read sector failed\n" );
+	return false;
 }
 
 
@@ -1447,12 +1539,17 @@ bool FDC_ReadSectorFromFloppy(void)
 bool FDC_WriteSectorFromFloppy(void)
 {
 	Uint32 Address;
+	int FrameCycles, HblCounterVideo, LineCycles;
+
 
 	/* Get DMA address */
 	Address = FDC_ReadDMAAddress();
 
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write sector addr=0x%x dev=%d sect=%d track=%d side=%d VBL=%d video_cyc=%d pc=%x\n" ,
-		Address, nReadWriteDev, nReadWriteSector, nReadWriteTrack, nReadWriteSide, nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc write sector addr=0x%x dev=%d sect=%d track=%d side=%d VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		Address, nReadWriteDev, nReadWriteSector, nReadWriteTrack, nReadWriteSide,
+		nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 
 	/* Write out 1 sector from our workspace */
 	if (Floppy_WriteSectors(nReadWriteDev, &STRam[Address], nReadWriteSector, nReadWriteTrack, nReadWriteSide, 1, NULL))
@@ -1464,12 +1561,12 @@ bool FDC_WriteSectorFromFloppy(void)
 			nReadWriteSector = 1;
 			nReadWriteTrack++;
 		}
-		return TRUE;
+		return true;
 	}
 
 	/* Failed */
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write sector failed\n" );
-	return FALSE;
+	LOG_TRACE(TRACE_FDC, "fdc write sector failed\n" );
+	return false;
 }
 
 
@@ -1502,6 +1599,8 @@ void FDC_DMADataFromFloppy(void)
 void FDC_DmaModeControl_WriteWord(void)
 {
 	Uint16 DMAModeControl_ff8606wr_prev;                     /* stores previous write to 0xff8606 for 'toggle' checks */
+	int FrameCycles, HblCounterVideo, LineCycles;
+
 
 	if (nIoMemAccessSize == SIZE_BYTE)
 	{
@@ -1513,8 +1612,10 @@ void FDC_DmaModeControl_WriteWord(void)
 	DMAModeControl_ff8606wr_prev = DMAModeControl_ff8606wr;  /* Store previous to check for _read/_write toggle (DMA reset) */
 	DMAModeControl_ff8606wr = IoMem_ReadWord(0xff8606);      /* Store to DMA Mode control */
 
-	HATARI_TRACE ( HATARI_TRACE_FDC , "fdc write 8606 ctrl=0x%x VBL=%d video_cyc=%d pc=%x\n" ,
-		DMAModeControl_ff8606wr , nVBLs , Cycles_GetCounter(CYCLES_COUNTER_VIDEO) , M68000_GetPC() );
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
+	LOG_TRACE(TRACE_FDC, "fdc write 8606 ctrl=0x%x VBL=%d video_cyc=%d %d@%d pc=%x\n" ,
+		DMAModeControl_ff8606wr , nVBLs , FrameCycles, LineCycles, HblCounterVideo , M68000_GetPC() );
 
 	/* When write to 0xff8606, check bit '8' toggle. This causes DMA status reset */
 	if ((DMAModeControl_ff8606wr_prev ^ DMAModeControl_ff8606wr) & 0x0100)
