@@ -8,22 +8,16 @@
 */
 const char File_fileid[] = "Hatari file.c : " __DATE__ " " __TIME__;
 
-#include <config.h>
-
-#include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/time.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <assert.h>
 #include <errno.h>
 #include <zlib.h>
 
-#if HAVE_STRINGS_H
-#include <strings.h>
-#endif
-
-#ifdef WIN32
+#if defined(WIN32) && !defined(_VCWIN_)
 #include <winsock2.h>
 #endif
 
@@ -31,6 +25,7 @@ const char File_fileid[] = "Hatari file.c : " __DATE__ " " __TIME__;
 #include "dialog.h"
 #include "file.h"
 #include "createBlankImage.h"
+#include "str.h"
 #include "zip.h"
 
 
@@ -79,13 +74,13 @@ void File_AddSlashToEndFileName(char *pszFileName)
 bool File_DoesFileExtensionMatch(const char *pszFileName, const char *pszExtension)
 {
 	if (strlen(pszFileName) < strlen(pszExtension))
-		return FALSE;
+		return false;
 	/* Is matching extension? */
 	if (!strcasecmp(&pszFileName[strlen(pszFileName)-strlen(pszExtension)], pszExtension))
-		return TRUE;
+		return true;
 
 	/* No */
-	return FALSE;
+	return false;
 }
 
 
@@ -98,17 +93,26 @@ bool File_DoesFileExtensionMatch(const char *pszFileName, const char *pszExtensi
 static bool File_IsRootFileName(const char *pszFileName)
 {
 	if (pszFileName[0] == '\0')     /* If NULL string return! */
-		return FALSE;
+		return false;
 
 	if (pszFileName[0] == PATHSEP)
-		return TRUE;
+		return true;
 
 #ifdef WIN32
 	if (pszFileName[1] == ':')
-		return TRUE;
+		return true;
 #endif
 
-	return FALSE;
+#ifdef GEKKO
+	if (strlen(pszFileName) > 2 && pszFileName[2] == ':')	// sd:
+		return true;
+	if (strlen(pszFileName) > 3 && pszFileName[3] == ':')	// fat:
+		return true;
+	if (strlen(pszFileName) > 4 && pszFileName[4] == ':')	// fat3:
+		return true;
+#endif
+
+	return false;
 }
 
 
@@ -147,13 +151,13 @@ bool File_DirExists(const char *path)
 bool File_DoesFileNameEndWithSlash(char *pszFileName)
 {
 	if (pszFileName[0] == '\0')    /* If NULL string return! */
-		return FALSE;
+		return false;
 	
 	/* Does string end in a '/'? */
 	if (pszFileName[strlen(pszFileName)-1] == PATHSEP)
-		return TRUE;
+		return true;
 	
-	return FALSE;
+	return false;
 }
 
 
@@ -166,7 +170,7 @@ bool File_DoesFileNameEndWithSlash(char *pszFileName)
 Uint8 *File_Read(const char *pszFileName, long *pFileSize, const char * const ppszExts[])
 {
 	char *filepath = NULL;
-	void *pFile = NULL;
+	Uint8 *pFile = NULL;
 	long FileSize = 0;
 
 	/* Does the file exist? If not, see if can scan for other extensions and try these */
@@ -243,14 +247,14 @@ Uint8 *File_Read(const char *pszFileName, long *pFileSize, const char * const pp
  */
 bool File_Save(const char *pszFileName, const Uint8 *pAddress, size_t Size, bool bQueryOverwrite)
 {
-	bool bRet = FALSE;
+	bool bRet = false;
 
 	/* Check if need to ask user if to overwrite */
 	if (bQueryOverwrite)
 	{
 		/* If file exists, ask if OK to overwrite */
 		if (!File_QueryOverwrite(pszFileName))
-			return FALSE;
+			return false;
 	}
 
 	/* Normal file or gzipped file? */
@@ -263,7 +267,7 @@ bool File_Save(const char *pszFileName, const Uint8 *pAddress, size_t Size, bool
 		{
 			/* Write data, set success flag */
 			if (gzwrite(hGzFile, pAddress, Size) == (int)Size)
-				bRet = TRUE;
+				bRet = true;
 
 			gzclose(hGzFile);
 		}
@@ -277,7 +281,7 @@ bool File_Save(const char *pszFileName, const Uint8 *pAddress, size_t Size, bool
 		{
 			/* Write data, set success flag */
 			if (fwrite(pAddress, 1, Size, hDiskFile) == Size)
-				bRet = TRUE;
+				bRet = true;
 
 			fclose(hDiskFile);
 		}
@@ -322,9 +326,9 @@ bool File_Exists(const char *filename)
 	    (buf.st_mode & (S_IRUSR|S_IWUSR)) && !(buf.st_mode & S_IFDIR))
 	{
 		/* file points to user readable regular file */
-		return TRUE;
+		return true;
 	}
-	return FALSE;
+	return false;
 }
 
 
@@ -337,9 +341,9 @@ bool File_DirectoryExists(const char *psDirName)
 	struct stat buf;
 	if (stat(psDirName, &buf) == 0 && (buf.st_mode & S_IFDIR))
 	{
-		return TRUE;
+		return true;
 	}
-	return FALSE;
+	return false;
 }
 
 
@@ -351,7 +355,7 @@ bool File_QueryOverwrite(const char *pszFileName)
 {
 	const char *fmt;
 	char *szString;
-	bool ret = TRUE;
+	bool ret = true;
 
 	/* Try and find if file exists */
 	if (File_Exists(pszFileName))
@@ -384,7 +388,7 @@ char * File_FindPossibleExtFileName(const char *pszFileName, const char * const
 	if (!szSrcDir)
 	{
 		perror("File_FindPossibleExtFileName");
-		return FALSE;
+		return false;
 	}
 	szSrcName = szSrcDir + FILENAME_MAX;
 	szSrcExt = szSrcName + FILENAME_MAX;
@@ -590,6 +594,7 @@ FILE *File_Close(FILE *fp)
  */
 bool File_InputAvailable(FILE *fp)
 {
+#if HAVE_SELECT
 	fd_set rfds;
 	struct timeval tv;
 	int fh;
@@ -611,6 +616,7 @@ bool File_InputAvailable(FILE *fp)
 
 	if (ret > 0)
 		return true;    /* Data available */
+#endif
 
 	return false;
 }
