@@ -33,7 +33,7 @@ static SGOBJ aboutdlg[] =
 	{ SGTEXT, 0, 0, 1,18, 38,1, "hope that it will be useful, but" },
 	{ SGTEXT, 0, 0, 1,19, 38,1, "WITHOUT ANY WARRANTY. See the GNU Ge-" },
 	{ SGTEXT, 0, 0, 1,20, 38,1, "neral Public License for more details." },
-	{ SGBUTTON, SG_DEFAULT, 0, 16,23, 8,1, "Okay" },
+	{ SGBUTTON, SG_DEFAULT, 0, 16,23, 8,1, "OK" },
 	{ -1, 0, 0, 0,0, 0,0, NULL }
 };
 
@@ -44,6 +44,9 @@ static SGOBJ aboutdlg[] =
 */
 void Dialog_AboutDlg(void)
 {
+	/* Center PROG_NAME title string */
+	aboutdlg[1].x = (aboutdlg[0].w - strlen(PROG_NAME)) / 2;
+
 	SDLGui_CenterDlg(aboutdlg);
 	SDLGui_DoDialog(aboutdlg, NULL);
 }
