@@ -4,7 +4,7 @@
   This file is distributed under the GNU Public License, version 2 or at
   your option any later version. Read the file gpl.txt for details.
 */
-const char DlgJoystick_rcsid[] = "Hatari $Id: dlgJoystick.c,v 1.12 2008-06-08 16:07:40 eerot Exp $";
+const char DlgJoystick_fileid[] = "Hatari dlgJoystick.c : " __DATE__ " " __TIME__;
 
 #include "main.h"
 #include "configuration.h"
@@ -110,7 +110,7 @@ static void DlgJoystick_DefineOneKey(char *pType, int *pKey)
 		}
 		else if (sdlEvent.type == SDL_QUIT)
 		{
-			bQuitProgram = TRUE;
+			bQuitProgram = true;
 			return;
 		}
 	} while (sdlEvent.type != SDL_KEYUP);
@@ -177,12 +177,12 @@ static void DlgJoystick_ReadValuesFromConf(int nActJoy, int nMaxId)
 */
 static void DlgJoystick_WriteValuesToConf(int nActJoy)
 {
-	int i;
-	for (i = DLGJOY_DISABLED; i <= DLGJOY_USEKEYS; i++)
+	JOYSTICKMODE jmi;
+	for (jmi = JOYSTICK_DISABLED; jmi <= JOYSTICK_KEYBOARD; jmi++)
 	{
-		if (joydlg[i].state & SG_SELECTED)
+		if (joydlg[jmi + DLGJOY_DISABLED].state & SG_SELECTED)
 		{
-			ConfigureParams.Joysticks.Joy[nActJoy].nJoystickMode = i - DLGJOY_DISABLED;
+			ConfigureParams.Joysticks.Joy[nActJoy].nJoystickMode = jmi;
 			break;
 		}
 	}
