@@ -50,7 +50,7 @@ HDCOMMAND HDCCommand;
 FILE *hd_image_file = NULL;
 int nPartitions = 0;
 short int HDCSectorCount;
-bool bAcsiEmuOn = FALSE;
+bool bAcsiEmuOn = false;
 
 static Uint32 nLastBlockAddr;
 static bool bSetLastBlockAddr;
@@ -118,9 +118,9 @@ static void HDC_Cmd_Seek(void)
 		nLastError = HD_REQSENS_INVADDR;
 	}
 
-	FDC_SetDMAStatus(FALSE);              /* no DMA error */
+	FDC_SetDMAStatus(false);              /* no DMA error */
 	FDC_AcknowledgeInterrupt();
-	bSetLastBlockAddr = TRUE;
+	bSetLastBlockAddr = true;
 	//FDCSectorCountRegister = 0;
 }
 
@@ -139,11 +139,11 @@ static void HDC_Cmd_Inquiry(void)
 	memcpy(&STRam[FDC_ReadDMAAddress()], inquiry_bytes,
 	       HD_SECTORCOUNT(HDCCommand));
 
-	FDC_SetDMAStatus(FALSE);              /* no DMA error */
+	FDC_SetDMAStatus(false);              /* no DMA error */
 	FDC_AcknowledgeInterrupt();
 	HDCCommand.returnCode = HD_STATUS_OK;
 	nLastError = HD_REQSENS_OK;
-	bSetLastBlockAddr = FALSE;
+	bSetLastBlockAddr = false;
 	//FDCSectorCountRegister = 0;
 }
 
@@ -229,7 +229,7 @@ static void HDC_Cmd_RequestSense(void)
 
 	memcpy(&STRam[nDmaAddr], retbuf, nRetLen);
 
-	FDC_SetDMAStatus(FALSE);            /* no DMA error */
+	FDC_SetDMAStatus(false);            /* no DMA error */
 	FDC_AcknowledgeInterrupt();
 	HDCCommand.returnCode = HD_STATUS_OK;
 	//FDCSectorCountRegister = 0;
@@ -287,9 +287,9 @@ static void HDC_Cmd_ModeSense(void)
 		nLastError = HD_REQSENS_INVARG;
 	}
 
-	FDC_SetDMAStatus(FALSE);            /* no DMA error */
+	FDC_SetDMAStatus(false);            /* no DMA error */
 	FDC_AcknowledgeInterrupt();
-	bSetLastBlockAddr = FALSE;
+	bSetLastBlockAddr = false;
 	//FDCSectorCountRegister = 0;
 }
 
@@ -306,11 +306,11 @@ static void HDC_Cmd_FormatDrive(void)
 
 	/* Should erase the whole image file here... */
 
-	FDC_SetDMAStatus(FALSE);            /* no DMA error */
+	FDC_SetDMAStatus(false);            /* no DMA error */
 	FDC_AcknowledgeInterrupt();
 	HDCCommand.returnCode = HD_STATUS_OK;
 	nLastError = HD_REQSENS_OK;
-	bSetLastBlockAddr = FALSE;
+	bSetLastBlockAddr = false;
 	//FDCSectorCountRegister = 0;
 }
 
@@ -321,6 +321,8 @@ static void HDC_Cmd_FormatDrive(void)
  */
 static void HDC_Cmd_WriteSector(void)
 {
+	int n = 0;
+
 	nLastBlockAddr = HDC_GetOffset();
 
 	/* seek to the position */
@@ -331,21 +333,29 @@ static void HDC_Cmd_WriteSector(void)
 	}
 	else
 	{
-		HDCCommand.returnCode = HD_STATUS_OK;
-		nLastError = HD_REQSENS_OK;
-
 		/* write - if allowed */
 #ifndef DISALLOW_HDC_WRITE
-		fwrite(&STRam[FDC_ReadDMAAddress()], 512, HD_SECTORCOUNT(HDCCommand),
-		       hd_image_file);
+		n = fwrite(&STRam[FDC_ReadDMAAddress()], 512,
+		           HD_SECTORCOUNT(HDCCommand), hd_image_file);
 #endif
+		if (n == HD_SECTORCOUNT(HDCCommand))
+		{
+			HDCCommand.returnCode = HD_STATUS_OK;
+			nLastError = HD_REQSENS_OK;
+		}
+		else
+		{
+			HDCCommand.returnCode = HD_STATUS_ERROR;
+			nLastError = HD_REQSENS_WRITEERR;
+		}
+
 		/* Update DMA counter */
-		FDC_WriteDMAAddress(FDC_ReadDMAAddress() + 512*HD_SECTORCOUNT(HDCCommand));
+		FDC_WriteDMAAddress(FDC_ReadDMAAddress() + 512*n);
 	}
 
-	FDC_SetDMAStatus(FALSE);              /* no DMA error */
+	FDC_SetDMAStatus(false);              /* no DMA error */
 	FDC_AcknowledgeInterrupt();
-	bSetLastBlockAddr = TRUE;
+	bSetLastBlockAddr = true;
 	//FDCSectorCountRegister = 0;
 }
 
@@ -356,6 +366,8 @@ static void HDC_Cmd_WriteSector(void)
  */
 static void HDC_Cmd_ReadSector(void)
 {
+	int n;
+
 	nLastBlockAddr = HDC_GetOffset();
 
 #ifdef HDC_VERBOSE
@@ -371,18 +383,26 @@ static void HDC_Cmd_ReadSector(void)
 	}
 	else
 	{
-		fread(&STRam[FDC_ReadDMAAddress()], 512, HD_SECTORCOUNT(HDCCommand),
-		      hd_image_file);
-		HDCCommand.returnCode = HD_STATUS_OK;
-		nLastError = HD_REQSENS_OK;
+		n = fread(&STRam[FDC_ReadDMAAddress()], 512,
+		          HD_SECTORCOUNT(HDCCommand), hd_image_file);
+		if (n == HD_SECTORCOUNT(HDCCommand))
+		{
+			HDCCommand.returnCode = HD_STATUS_OK;
+			nLastError = HD_REQSENS_OK;
+		}
+		else
+		{
+			HDCCommand.returnCode = HD_STATUS_ERROR;
+			nLastError = HD_REQSENS_NOSECTOR;
+		}
 
 		/* Update DMA counter */
-		FDC_WriteDMAAddress(FDC_ReadDMAAddress() + 512*HD_SECTORCOUNT(HDCCommand));
+		FDC_WriteDMAAddress(FDC_ReadDMAAddress() + 512*n);
 	}
 
-	FDC_SetDMAStatus(FALSE);              /* no DMA error */
+	FDC_SetDMAStatus(false);              /* no DMA error */
 	FDC_AcknowledgeInterrupt();
-	bSetLastBlockAddr = TRUE;
+	bSetLastBlockAddr = true;
 	//FDCSectorCountRegister = 0;
 }
 
@@ -425,8 +445,8 @@ void HDC_EmulateCommandPacket()
 		Log_Printf(LOG_TODO, "HDC: MODE SELECT call not implemented yet.\n");
 		HDCCommand.returnCode = HD_STATUS_OK;
 		nLastError = HD_REQSENS_OK;
-		bSetLastBlockAddr = FALSE;
-		FDC_SetDMAStatus(FALSE);
+		bSetLastBlockAddr = false;
+		FDC_SetDMAStatus(false);
 		FDC_AcknowledgeInterrupt();
 		break;
 
@@ -446,7 +466,7 @@ void HDC_EmulateCommandPacket()
 	 default:
 		HDCCommand.returnCode = HD_STATUS_ERROR;
 		nLastError = HD_REQSENS_OPCODE;
-		bSetLastBlockAddr = FALSE;
+		bSetLastBlockAddr = false;
 		FDC_AcknowledgeInterrupt();
 		break;
 	}
@@ -550,7 +570,11 @@ static void HDC_GetInfo(void)
 	offset = ftell(hd_image_file);
 
 	fseek(hd_image_file, HD_PARTITIONTABLE_OFFSET, 0);
-	fread(hdinfo, HD_PARTITIONTABLE_SIZE, 1, hd_image_file);
+	if (fread(hdinfo, HD_PARTITIONTABLE_SIZE, 1, hd_image_file) != 1)
+	{
+		perror("HDC_GetInfo");
+		return;
+	}
 
 #ifdef HDC_VERBOSE
 	size = (((unsigned long) hdinfo[0] << 24)
@@ -580,20 +604,20 @@ static void HDC_GetInfo(void)
  */
 bool HDC_Init(char *filename)
 {
-	bAcsiEmuOn = FALSE;
+	bAcsiEmuOn = false;
 
 	/* Sanity check - is file length a multiple of 512? */
 	if (File_Length(filename) & 0x1ff)
 	{
 		Log_Printf(LOG_ERROR, "HD file '%s' has strange size!\n", filename);
-		return FALSE;
+		return false;
 	}
 
 
 	if ((hd_image_file = fopen(filename, "rb+")) == NULL)
 	{
 		Log_Printf(LOG_ERROR, "Can not open HD file '%s'!\n", filename);
-		return FALSE;
+		return false;
 	}
 
 	HDC_GetInfo();
@@ -601,9 +625,9 @@ bool HDC_Init(char *filename)
 	/* set number of partitions */
 	nNumDrives += nPartitions;
 
-	bAcsiEmuOn = TRUE;
+	bAcsiEmuOn = true;
 
-	return TRUE;
+	return true;
 }
 
 
@@ -622,7 +646,7 @@ void HDC_UnInit(void)
 
 	nNumDrives -= nPartitions;
 	nPartitions = 0;
-	bAcsiEmuOn = FALSE;
+	bAcsiEmuOn = false;
 }
 
 
@@ -633,10 +657,6 @@ void HDC_UnInit(void)
  */
 void HDC_WriteCommandPacket(void)
 {
-	/* check status byte */
-	if ((DMAModeControl_ff8606wr & 0x0018) != 8)
-		return;
-
 	/* is HDC emulation enabled? */
 	if (!bAcsiEmuOn)
 		return;
@@ -663,7 +683,7 @@ void HDC_WriteCommandPacket(void)
 		else
 		{
 			/* No drive/controller */
-			FDC_SetDMAStatus(TRUE);
+			FDC_SetDMAStatus(true);
 			//FDC_AcknowledgeInterrupt();
 			HDCCommand.returnCode = HD_STATUS_ERROR;
 			//FDCSectorCountRegister = 0;
@@ -677,7 +697,7 @@ void HDC_WriteCommandPacket(void)
 		if (HD_CONTROLLER(HDCCommand) == 0)
 		{
 			FDC_AcknowledgeInterrupt();
-			FDC_SetDMAStatus(FALSE);
+			FDC_SetDMAStatus(false);
 			HDCCommand.returnCode = HD_STATUS_OK;
 		}
 		else
