@@ -83,7 +83,7 @@ static bool bMouseEnabledDuringReset;
 static Uint8 ACIAControlRegister = 0;
 static Uint8 ACIAStatusRegister = ACIA_STATUS_REGISTER__TX_BUFFER_EMPTY;  /* Pass when read 0xfffc00 */
 static Uint8 ACIAByte;				/* When a byte has arrived at the ACIA (from the keyboard) it is stored here */
-static bool bByteInTransitToACIA = FALSE;	/* Is a byte being sent to the ACIA from the keyboard? */
+static bool bByteInTransitToACIA = false;	/* Is a byte being sent to the ACIA from the keyboard? */
 
 /*
   6850 ACIA (Asynchronous Communications Inferface Apdater)
@@ -277,11 +277,11 @@ static void IKBD_CustomCodeHandler_DragonnelsMenu_Write ( Uint8 aciabyte );
 int	MemoryLoadNbBytesTotal = 0;			/* total number of bytes to send with the command 0x20 */
 int	MemoryLoadNbBytesLeft = 0;			/* number of bytes that remain to be sent  */
 Uint32	MemoryLoadCrc = 0xffffffff;			/* CRC of the bytes sent to the ikbd */
-int	MemoryExeNbBytes = 0;				/* current number of bytes sent to the ikbd when IKBD_ExeMode is TRUE */
+int	MemoryExeNbBytes = 0;				/* current number of bytes sent to the ikbd when IKBD_ExeMode is true */
 
 void	(*pIKBD_CustomCodeHandler_Read) ( void );
 void	(*pIKBD_CustomCodeHandler_Write) ( Uint8 );
-bool	IKBD_ExeMode = FALSE;
+bool	IKBD_ExeMode = false;
 
 Uint8	ScanCodeState[ 128 ];				/* state of each key : 0=released 1=pressed */
 
@@ -335,7 +335,7 @@ CustomCodeDefinitions[] =
  */
 void ACIA_Reset(void)
 {
-	bByteInTransitToACIA = FALSE;
+	bByteInTransitToACIA = false;
 	ACIAControlRegister = 0;
 	ACIAStatusRegister = ACIA_STATUS_REGISTER__TX_BUFFER_EMPTY;
 }
@@ -352,17 +352,17 @@ void ACIA_Reset(void)
 
 void IKBD_Reset_ExeMode ( void )
 {
-	HATARI_TRACE ( HATARI_TRACE_IKBD_EXEC, "ikbd custom exe off\n" );
+	LOG_TRACE(TRACE_IKBD_EXEC, "ikbd custom exe off\n");
 
 	/* Reset any custom code run with the Execute command 0x22 */
 	MemoryLoadNbBytesLeft = 0;
 	pIKBD_CustomCodeHandler_Read = NULL;
 	pIKBD_CustomCodeHandler_Write = NULL;
-	IKBD_ExeMode = FALSE;
+	IKBD_ExeMode = false;
 
 	Keyboard.BufferHead = Keyboard.BufferTail = 0;	/* flush all queued bytes that would be read in $fffc02 */
-	bByteInTransitToACIA = FALSE;
-	IKBD_AddKeyToKeyboardBuffer(0xF0);		/* Assume OK, return correct code */
+	bByteInTransitToACIA = false;
+	// IKBD_AddKeyToKeyboardBuffer(0xF0);		/* Assume OK, return correct code */
 	IKBD_AddKeyToKeyboardBuffer(0xF1);		/* [NP] Dragonnels demo needs this */
 }
 
@@ -375,7 +375,7 @@ void IKBD_Reset(bool bCold)
 	/* Reset internal keyboard processor details */
 	if (bCold)
 	{
-		KeyboardProcessor.bReset = FALSE;
+		KeyboardProcessor.bReset = false;
 		if (Int_InterruptActive(INTERRUPT_IKBD_RESETTIMER))
 			Int_RemovePendingInterrupt(INTERRUPT_IKBD_RESETTIMER);
 	}
@@ -413,17 +413,17 @@ void IKBD_Reset(bool bCold)
 	Keyboard.LButtonHistory = Keyboard.RButtonHistory = 0;
 
 	/* Store bool for when disable mouse or joystick */
-	bMouseDisabled = bJoystickDisabled = FALSE;
+	bMouseDisabled = bJoystickDisabled = false;
 	/* do emulate hardware 'quirk' where if disable both with 'x' time
 	 * of a RESET command they are ignored! */
-	bDuringResetCriticalTime = bBothMouseAndJoy = FALSE;
-	bMouseEnabledDuringReset = FALSE;
+	bDuringResetCriticalTime = bBothMouseAndJoy = false;
+	bMouseEnabledDuringReset = false;
 
 	/* Remove any custom handlers used to emulate code loaded to the 6301's RAM */
 	IKBD_Reset_ExeMode ();
 
 	/* Add auto-update function to the queue */
-	Int_AddRelativeInterrupt(80000, INT_CPU_CYCLE, INTERRUPT_IKBD_AUTOSEND);
+	Int_AddRelativeInterrupt(150000, INT_CPU_CYCLE, INTERRUPT_IKBD_AUTOSEND);
 }
 
 
@@ -452,7 +452,7 @@ void IKBD_MemorySnapShot_Capture(bool bSave)
 	/* restore custom 6301 program if needed */
 	MemorySnapShot_Store(&IKBD_ExeMode, sizeof(IKBD_ExeMode));
 	MemorySnapShot_Store(&MemoryLoadCrc, sizeof(MemoryLoadCrc));
-	if ( ( bSave == FALSE ) && ( IKBD_ExeMode == TRUE ) )	/* restoring a snapshot with active 6301 emulation */
+	if ((bSave == false) && (IKBD_ExeMode == true)) 	/* restoring a snapshot with active 6301 emulation */
 	{
 		for ( i = 0 ; i < sizeof ( CustomCodeDefinitions ) / sizeof ( CustomCodeDefinitions[0] ); i++ )
 			if ( CustomCodeDefinitions[ i ].MainProgCrc == MemoryLoadCrc )
@@ -466,7 +466,7 @@ void IKBD_MemorySnapShot_Capture(bool bSave)
 			}
 
 		if ( i >= sizeof ( CustomCodeDefinitions ) / sizeof ( CustomCodeDefinitions[0] ) )	/* not found (should not happen) */
-			IKBD_ExeMode = FALSE;			/* turn off exe mode */
+			IKBD_ExeMode = false;			/* turn off exe mode */
 	}
 }
 
@@ -544,7 +544,7 @@ static void IKBD_CheckForDoubleClicks(void)
 		if (Keyboard.LButtonDblClk >= 13)             /* Check for end of sequence */
 		{
 			Keyboard.LButtonDblClk = 0;
-			Keyboard.bLButtonDown = FALSE;
+			Keyboard.bLButtonDown = false;
 		}
 	}
 	if (Keyboard.RButtonDblClk)
@@ -570,7 +570,7 @@ static void IKBD_CheckForDoubleClicks(void)
 		if (Keyboard.RButtonDblClk >= 13)             /* Check for end of sequence */
 		{
 			Keyboard.RButtonDblClk = 0;
-			Keyboard.bRButtonDown = FALSE;
+			Keyboard.bRButtonDown = false;
 		}
 	}
 
@@ -592,14 +592,14 @@ static bool IKBD_ButtonBool(int Button)
 {
 	/* Button pressed? */
 	if (Button)
-		return TRUE;
-	return FALSE;
+		return true;
+	return false;
 }
 
 
 /*-----------------------------------------------------------------------*/
 /**
- * Return TRUE if buttons match, use this as buttons are a mask and not boolean
+ * Return true if buttons match, use this as buttons are a mask and not boolean
  */
 static bool IKBD_ButtonsEqual(int Button1,int Button2)
 {
@@ -656,7 +656,7 @@ static void IKBD_SendRelMousePacket(void)
 	        || (!IKBD_ButtonsEqual(Keyboard.bOldLButtonDown,Keyboard.bLButtonDown)) || (!IKBD_ButtonsEqual(Keyboard.bOldRButtonDown,Keyboard.bRButtonDown)) )
 	{
 		/* Send packet to keyboard process */
-		while (TRUE)
+		while (true)
 		{
 			ByteRelX = KeyboardProcessor.Mouse.DeltaX;
 			if (ByteRelX>127)  ByteRelX = 127;
@@ -741,7 +741,7 @@ static void IKBD_SelAutoJoysticks(void)
  */
 static void IKBD_SendOnMouseAction(void)
 {
-	bool bReportPosition = FALSE;
+	bool bReportPosition = false;
 
 	/* Report buttons as keys? Do in relative/absolute mode */
 	if (KeyboardProcessor.Mouse.Action&0x4)
@@ -771,13 +771,13 @@ static void IKBD_SendOnMouseAction(void)
 			/* Did 'press' mouse buttons? */
 			if ( (IKBD_ButtonBool(Keyboard.bLButtonDown) && (!IKBD_ButtonBool(Keyboard.bOldLButtonDown))) )
 			{
-				bReportPosition = TRUE;
+				bReportPosition = true;
 				KeyboardProcessor.Abs.PrevReadAbsMouseButtons &= ~0x04;
 				KeyboardProcessor.Abs.PrevReadAbsMouseButtons |= 0x02;
 			}
 			if ( (IKBD_ButtonBool(Keyboard.bRButtonDown) && (!IKBD_ButtonBool(Keyboard.bOldRButtonDown))) )
 			{
-				bReportPosition = TRUE;
+				bReportPosition = true;
 				KeyboardProcessor.Abs.PrevReadAbsMouseButtons &= ~0x01;
 				KeyboardProcessor.Abs.PrevReadAbsMouseButtons |= 0x08;
 			}
@@ -788,13 +788,13 @@ static void IKBD_SendOnMouseAction(void)
 			/* Did 'release' mouse buttons? */
 			if ( (IKBD_ButtonBool(Keyboard.bOldLButtonDown) && (!IKBD_ButtonBool(Keyboard.bLButtonDown))) )
 			{
-				bReportPosition = TRUE;
+				bReportPosition = true;
 				KeyboardProcessor.Abs.PrevReadAbsMouseButtons &= ~0x08;
 				KeyboardProcessor.Abs.PrevReadAbsMouseButtons |= 0x01;
 			}
 			if ( (IKBD_ButtonBool(Keyboard.bOldRButtonDown) && (!IKBD_ButtonBool(Keyboard.bRButtonDown))) )
 			{
-				bReportPosition = TRUE;
+				bReportPosition = true;
 				KeyboardProcessor.Abs.PrevReadAbsMouseButtons &= ~0x02;
 				KeyboardProcessor.Abs.PrevReadAbsMouseButtons |= 0x04;
 			}
@@ -806,7 +806,7 @@ static void IKBD_SendOnMouseAction(void)
 			/* Only report if mouse in absolute mode */
 			if (KeyboardProcessor.MouseMode==AUTOMODE_MOUSEABS)
 			{
-				HATARI_TRACE(HATARI_TRACE_IKBD_ALL, "Report ABS on MouseAction\n");
+				LOG_TRACE(TRACE_IKBD_ALL, "Report ABS on MouseAction\n");
 				IKBD_Cmd_ReadAbsMousePos();
 			}
 		}
@@ -923,13 +923,13 @@ static void IKBD_SendAutoKeyboardCommands(void)
 		/* As we simulating space bar? */
 		if (JoystickSpaceBar==JOYSTICK_SPACE_DOWN)
 		{
-			IKBD_PressSTKey(57,TRUE);         /* Press */
+			IKBD_PressSTKey(57, true);         /* Press */
 			JoystickSpaceBar = JOYSTICK_SPACE_UP;
 		}
 		else   //if (JoystickSpaceBar==JOYSTICK_SPACE_UP) {
 		{
-			IKBD_PressSTKey(57,FALSE);        /* Release */
-			JoystickSpaceBar = FALSE;         /* Complete */
+			IKBD_PressSTKey(57, false);       /* Release */
+			JoystickSpaceBar = false;         /* Complete */
 		}
 	}
 }
@@ -959,7 +959,7 @@ void IKBD_InterruptHandler_AutoSend(void)
 	}
 
 	/* Trigger this auto-update function again after a while */
-	Int_AddRelativeInterrupt(60000, INT_CPU_CYCLE, INTERRUPT_IKBD_AUTOSEND);
+	Int_AddRelativeInterrupt(150000, INT_CPU_CYCLE, INTERRUPT_IKBD_AUTOSEND);
 
 	/* We don't send keyboard data automatically within the first few
 	 * VBLs to avoid that TOS gets confused during its boot time */
@@ -988,10 +988,10 @@ static void IKBD_CheckResetDisableBug(void)
 			/* Emulate relative mouse and joystick reports being turned back on */
 			KeyboardProcessor.MouseMode = AUTOMODE_MOUSEREL;
 			KeyboardProcessor.JoystickMode = AUTOMODE_JOYSTICK;
-			bBothMouseAndJoy = TRUE;
+			bBothMouseAndJoy = true;
 
-			HATARI_TRACE(HATARI_TRACE_IKBD_ALL, "IKBD Mouse+Joystick disabled "
-			             "during RESET. Revert.\n");
+			LOG_TRACE(TRACE_IKBD_ALL, "IKBD Mouse+Joystick disabled "
+			          "during RESET. Revert.\n");
 		}
 	}
 }
@@ -1008,11 +1008,11 @@ void IKBD_InterruptHandler_ResetTimer(void)
 	Int_AcknowledgeInterrupt();
 
 	/* Turn processor on; can now process commands */
-	KeyboardProcessor.bReset = TRUE;
+	KeyboardProcessor.bReset = true;
 
 	/* Critical timer is over */
-	bDuringResetCriticalTime = FALSE;
-	bMouseEnabledDuringReset = FALSE;
+	bDuringResetCriticalTime = false;
+	bMouseEnabledDuringReset = false;
 }
 
 
@@ -1030,12 +1030,13 @@ void IKBD_InterruptHandler_ResetTimer(void)
  * 0x80
  * 0x01
  *
- * Performs self test and checks for stuck (closed) keys, if OK returns 0xF0. Otherwise
- * returns break codes for keys
+ * Performs self test and checks for stuck (closed) keys, if OK returns 0xF0 or
+ * 0xF1. Otherwise returns break codes for keys (not emulated).
  */
 static void IKBD_Cmd_Reset(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_Reset\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_Reset. VBLs=%i framecyc=%i\n",
+	          nVBLs, Cycles_GetCounter(CYCLES_COUNTER_VIDEO));
 
 	/* Check for error series of bytes, eg 0x80,0x01 */
 	if (Keyboard.InputBuffer[1] == 0x01)
@@ -1049,20 +1050,29 @@ static void IKBD_Cmd_Reset(void)
 		KeyboardProcessor.Abs.MaxY = ABS_MAY_Y_ONRESET;
 		KeyboardProcessor.Abs.PrevReadAbsMouseButtons = ABS_PREVBUTTONS;
 
-		Keyboard.BufferHead = Keyboard.BufferTail = 0;	/* flush all queued bytes that would be read in $fffc02 */
-		IKBD_AddKeyToKeyboardBuffer(0xF0);		/* Assume OK, return correct code */
-		IKBD_AddKeyToKeyboardBuffer(0xF1);		/* [NP] Dragonnels demo needs this */
+		/* flush all queued bytes that would be read in $fffc02 */
+		Keyboard.BufferHead = Keyboard.BufferTail = 0;
+
+		/* This command returns either the byte 0xf0 or 0xf1 (depending
+		 * on the version of the IKBD ROM) when the reset has been
+		 * successful. Some notes:
+		 * - Dragonnels demo requires 0xf1 so we use only this value
+		 *   right now.
+		 * - Lotus Turbo Esprit 2 requires at least a delay of 50000
+		 *   cycles or it will crash during start up.
+		 */
+		IKBD_AddKeyToKeyboardBufferWithDelay(0xf1, 50000);
 
 		/* Start timer - some commands are send during this time they may be ignored (see real ST!) */
 		Int_AddRelativeInterrupt(IKBD_RESET_CYCLES, INT_CPU_CYCLE, INTERRUPT_IKBD_RESETTIMER);
 
 		/* Set this 'critical' flag, gets reset when timer expires */
-		bDuringResetCriticalTime = TRUE;
-		bMouseDisabled = bJoystickDisabled = FALSE;
-		bBothMouseAndJoy = FALSE;
-		bMouseEnabledDuringReset = FALSE;
+		bDuringResetCriticalTime = true;
+		bMouseDisabled = bJoystickDisabled = false;
+		bBothMouseAndJoy = false;
+		bMouseEnabledDuringReset = false;
 
-		HATARI_TRACE(HATARI_TRACE_IKBD_ALL, "IKBD reset done.\n");
+		LOG_TRACE(TRACE_IKBD_ALL, "IKBD reset done.\n");
 	}
 	/* else if not 0x80,0x01 just ignore */
 }
@@ -1086,8 +1096,8 @@ static void IKBD_Cmd_MouseAction(void)
 	KeyboardProcessor.Mouse.Action = Keyboard.InputBuffer[1];
 	KeyboardProcessor.Abs.PrevReadAbsMouseButtons = ABS_PREVBUTTONS;
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_MouseAction %d\n",
-	             (unsigned int)KeyboardProcessor.Mouse.Action);
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_MouseAction %d\n",
+	          (unsigned int)KeyboardProcessor.Mouse.Action);
 }
 
 
@@ -1106,9 +1116,9 @@ static void IKBD_Cmd_RelMouseMode(void)
 	 * type of packets. To emulate this feature, we've got to remember
 	 * that the mouse has been enabled during reset. */
 	if (bDuringResetCriticalTime)
-		bMouseEnabledDuringReset = TRUE;
+		bMouseEnabledDuringReset = true;
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_RelMouseMode\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_RelMouseMode\n");
 }
 
 
@@ -1129,8 +1139,8 @@ static void IKBD_Cmd_AbsMouseMode(void)
 	KeyboardProcessor.Abs.MaxX = (((unsigned int)Keyboard.InputBuffer[1])<<8) | (unsigned int)Keyboard.InputBuffer[2];
 	KeyboardProcessor.Abs.MaxY = (((unsigned int)Keyboard.InputBuffer[3])<<8) | (unsigned int)Keyboard.InputBuffer[4];
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_AbsMouseMode %d,%d\n",
-	             KeyboardProcessor.Abs.MaxX, KeyboardProcessor.Abs.MaxY);
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_AbsMouseMode %d,%d\n",
+	          KeyboardProcessor.Abs.MaxX, KeyboardProcessor.Abs.MaxY);
 }
 
 
@@ -1148,9 +1158,9 @@ static void IKBD_Cmd_MouseCursorKeycodes(void)
 	KeyboardProcessor.Mouse.KeyCodeDeltaX = Keyboard.InputBuffer[1];
 	KeyboardProcessor.Mouse.KeyCodeDeltaY = Keyboard.InputBuffer[2];
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_MouseCursorKeycodes %d,%d\n",
-	             (int)KeyboardProcessor.Mouse.KeyCodeDeltaX,
-	             (int)KeyboardProcessor.Mouse.KeyCodeDeltaY);
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_MouseCursorKeycodes %d,%d\n",
+	          (int)KeyboardProcessor.Mouse.KeyCodeDeltaX,
+	          (int)KeyboardProcessor.Mouse.KeyCodeDeltaY);
 }
 
 
@@ -1167,8 +1177,8 @@ static void IKBD_Cmd_SetMouseThreshold(void)
 	KeyboardProcessor.Mouse.XThreshold = (unsigned int)Keyboard.InputBuffer[1];
 	KeyboardProcessor.Mouse.YThreshold = (unsigned int)Keyboard.InputBuffer[2];
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetMouseThreshold %d,%d\n",
-	             KeyboardProcessor.Mouse.XThreshold, KeyboardProcessor.Mouse.YThreshold);
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetMouseThreshold %d,%d\n",
+	          KeyboardProcessor.Mouse.XThreshold, KeyboardProcessor.Mouse.YThreshold);
 }
 
 
@@ -1185,8 +1195,8 @@ static void IKBD_Cmd_SetMouseScale(void)
 	KeyboardProcessor.Mouse.XScale = (unsigned int)Keyboard.InputBuffer[1];
 	KeyboardProcessor.Mouse.YScale = (unsigned int)Keyboard.InputBuffer[2];
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetMouseScale %d,%d\n",
-	             KeyboardProcessor.Mouse.XScale, KeyboardProcessor.Mouse.YScale);
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetMouseScale %d,%d\n",
+	          KeyboardProcessor.Mouse.XScale, KeyboardProcessor.Mouse.YScale);
 }
 
 
@@ -1235,8 +1245,8 @@ static void IKBD_Cmd_ReadAbsMousePos(void)
 	IKBD_AddKeyToKeyboardBuffer((unsigned int)KeyboardProcessor.Abs.Y>>8);
 	IKBD_AddKeyToKeyboardBuffer((unsigned int)KeyboardProcessor.Abs.Y&0xff);
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReadAbsMousePos %d,%d 0x%X\n",
-	             KeyboardProcessor.Abs.X, KeyboardProcessor.Abs.Y, Buttons);
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReadAbsMousePos %d,%d 0x%X\n",
+	          KeyboardProcessor.Abs.X, KeyboardProcessor.Abs.Y, Buttons);
 }
 
 
@@ -1257,8 +1267,8 @@ static void IKBD_Cmd_SetInternalMousePos(void)
 	KeyboardProcessor.Abs.X = (((unsigned int)Keyboard.InputBuffer[2])<<8) | (unsigned int)Keyboard.InputBuffer[3];
 	KeyboardProcessor.Abs.Y = (((unsigned int)Keyboard.InputBuffer[4])<<8) | (unsigned int)Keyboard.InputBuffer[5];
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetInternalMousePos %d,%d\n",
-	             KeyboardProcessor.Abs.X, KeyboardProcessor.Abs.Y);
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetInternalMousePos %d,%d\n",
+	          KeyboardProcessor.Abs.X, KeyboardProcessor.Abs.Y);
 }
 
 
@@ -1272,7 +1282,7 @@ static void IKBD_Cmd_SetYAxisDown(void)
 {
 	KeyboardProcessor.Mouse.YAxis = -1;
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetYAxisDown\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetYAxisDown\n");
 }
 
 
@@ -1286,7 +1296,7 @@ static void IKBD_Cmd_SetYAxisUp(void)
 {
 	KeyboardProcessor.Mouse.YAxis = 1;
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetYAxisUp\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetYAxisUp\n");
 }
 
 
@@ -1298,7 +1308,7 @@ static void IKBD_Cmd_SetYAxisUp(void)
  */
 static void IKBD_Cmd_StartKeyboardTransfer(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_StartKeyboardTransfer\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_StartKeyboardTransfer\n");
 }
 
 
@@ -1311,9 +1321,9 @@ static void IKBD_Cmd_StartKeyboardTransfer(void)
 static void IKBD_Cmd_TurnMouseOff(void)
 {
 	KeyboardProcessor.MouseMode = AUTOMODE_OFF;
-	bMouseDisabled = TRUE;
+	bMouseDisabled = true;
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_TurnMouseOff\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_TurnMouseOff\n");
 
 	IKBD_CheckResetDisableBug();
 }
@@ -1327,7 +1337,7 @@ static void IKBD_Cmd_TurnMouseOff(void)
  */
 static void IKBD_Cmd_StopKeyboardTransfer(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_StopKeyboardTransfer\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_StopKeyboardTransfer\n");
 }
 
 
@@ -1339,7 +1349,7 @@ static void IKBD_Cmd_StopKeyboardTransfer(void)
  */
 static void IKBD_Cmd_ReturnJoystickAuto(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReturnJoystickAuto\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReturnJoystickAuto\n");
 
 	KeyboardProcessor.JoystickMode = AUTOMODE_JOYSTICK;
 	KeyboardProcessor.MouseMode = AUTOMODE_OFF;
@@ -1349,9 +1359,9 @@ static void IKBD_Cmd_ReturnJoystickAuto(void)
 	if (bMouseEnabledDuringReset)
 	{
 		KeyboardProcessor.MouseMode = AUTOMODE_MOUSEREL;
-		bBothMouseAndJoy = TRUE;
-		HATARI_TRACE(HATARI_TRACE_IKBD_ALL, "IKBD joystick and mouse "
-		             "enabled during RESET. Mouse not disabled!\n");
+		bBothMouseAndJoy = true;
+		LOG_TRACE(TRACE_IKBD_ALL, "IKBD joystick and mouse "
+		          "enabled during RESET. Mouse not disabled!\n");
 	}
 
 	/* This command resets the internally previously stored joystick states */
@@ -1376,7 +1386,7 @@ static void IKBD_Cmd_ReturnJoystickAuto(void)
 static void IKBD_Cmd_StopJoystick(void)
 {
 	KeyboardProcessor.JoystickMode = AUTOMODE_OFF;
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_StopJoystick\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_StopJoystick\n");
 }
 
 
@@ -1392,7 +1402,7 @@ static void IKBD_Cmd_ReturnJoystick(void)
 	IKBD_AddKeyToKeyboardBuffer(Joy_GetStickData(0));
 	IKBD_AddKeyToKeyboardBuffer(Joy_GetStickData(1));
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReturnJoystick\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReturnJoystick\n");
 }
 
 
@@ -1410,7 +1420,7 @@ static void IKBD_Cmd_ReturnJoystick(void)
  */
 static void IKBD_Cmd_SetJoystickDuration(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetJoystickDuration\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetJoystickDuration\n");
 }
 
 
@@ -1425,7 +1435,7 @@ static void IKBD_Cmd_SetJoystickDuration(void)
  */
 static void IKBD_Cmd_SetJoystickFireDuration(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetJoystickFireDuration\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetJoystickFireDuration\n");
 }
 
 
@@ -1453,7 +1463,7 @@ static void IKBD_Cmd_SetJoystickFireDuration(void)
  */
 static void IKBD_Cmd_SetCursorForJoystick(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetCursorForJoystick\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetCursorForJoystick\n");
 }
 
 
@@ -1466,9 +1476,9 @@ static void IKBD_Cmd_SetCursorForJoystick(void)
 static void IKBD_Cmd_DisableJoysticks(void)
 {
 	KeyboardProcessor.JoystickMode = AUTOMODE_OFF;
-	bJoystickDisabled = TRUE;
+	bJoystickDisabled = true;
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_DisableJoysticks\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_DisableJoysticks\n");
 
 	IKBD_CheckResetDisableBug();
 }
@@ -1488,7 +1498,7 @@ static void IKBD_Cmd_DisableJoysticks(void)
  */
 static void IKBD_Cmd_SetClock(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_SetClock\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_SetClock\n");
 }
 
 
@@ -1541,7 +1551,7 @@ static void IKBD_Cmd_ReadClock(void)
 	IKBD_AddKeyToKeyboardBuffer(IKBD_ConvertToBCD(SystemTime->tm_min));   /* mm - Minute */
 	IKBD_AddKeyToKeyboardBuffer(IKBD_ConvertToBCD(SystemTime->tm_sec));   /* ss - Second */
 
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReadClock\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReadClock\n");
 }
 
 
@@ -1557,8 +1567,8 @@ static void IKBD_Cmd_ReadClock(void)
  */
 static void IKBD_Cmd_LoadMemory(void)
 {
-	HATARI_TRACE ( HATARI_TRACE_IKBD_CMDS , "IKBD_Cmd_LoadMemory addr 0x%x count %d\n" ,
-		( Keyboard.InputBuffer[1]<<8 ) + Keyboard.InputBuffer[2] , Keyboard.InputBuffer[3] );
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_LoadMemory addr 0x%x count %d\n",
+		  (Keyboard.InputBuffer[1] << 8) + Keyboard.InputBuffer[2], Keyboard.InputBuffer[3]);
 
 	MemoryLoadNbBytesTotal = Keyboard.InputBuffer[3];
 	MemoryLoadNbBytesLeft = MemoryLoadNbBytesTotal;
@@ -1580,7 +1590,7 @@ static void IKBD_Cmd_LoadMemory(void)
  */
 static void IKBD_Cmd_ReadMemory(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReadMemory\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReadMemory\n");
 }
 
 
@@ -1594,19 +1604,19 @@ static void IKBD_Cmd_ReadMemory(void)
  */
 static void IKBD_Cmd_Execute(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_Execute\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_Execute\n");
 
 	if ( pIKBD_CustomCodeHandler_Write )
 	{
-		HATARI_TRACE ( HATARI_TRACE_IKBD_EXEC, "ikbd execute addr 0x%x using custom handler\n" ,
-			( Keyboard.InputBuffer[1]<<8 ) + Keyboard.InputBuffer[2] );
+		LOG_TRACE(TRACE_IKBD_EXEC, "ikbd execute addr 0x%x using custom handler\n",
+			  (Keyboard.InputBuffer[1] << 8) + Keyboard.InputBuffer[2]);
 
-		IKBD_ExeMode = TRUE;				/* turn 6301's custom mode ON */
+		IKBD_ExeMode = true;				/* turn 6301's custom mode ON */
 	}
 	else							/* unknown code uploaded to ikbd RAM */
 	{
-		HATARI_TRACE ( HATARI_TRACE_IKBD_EXEC, "ikbd execute addr 0x%x ignored, no custom handler found\n" ,
-			( Keyboard.InputBuffer[1]<<8 ) + Keyboard.InputBuffer[2] );
+		LOG_TRACE(TRACE_IKBD_EXEC, "ikbd execute addr 0x%x ignored, no custom handler found\n",
+			  (Keyboard.InputBuffer[1] << 8) + Keyboard.InputBuffer[2]);
 	}
 }
 
@@ -1619,7 +1629,7 @@ static void IKBD_Cmd_Execute(void)
  */
 static void IKBD_Cmd_ReportMouseAction(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseAction\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseAction\n");
 
 	IKBD_AddKeyToKeyboardBufferWithDelay(0xf6, 30000);
 	IKBD_AddKeyToKeyboardBuffer(7);
@@ -1640,7 +1650,7 @@ static void IKBD_Cmd_ReportMouseAction(void)
  */
 static void IKBD_Cmd_ReportMouseMode(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseMode\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseMode\n");
 
 	IKBD_AddKeyToKeyboardBufferWithDelay(0xf6, 30000);
 	switch (KeyboardProcessor.MouseMode)
@@ -1684,7 +1694,7 @@ static void IKBD_Cmd_ReportMouseMode(void)
  */
 static void IKBD_Cmd_ReportMouseThreshold(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseThreshold\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseThreshold\n");
 
 	IKBD_AddKeyToKeyboardBufferWithDelay(0xf6, 30000);
 	IKBD_AddKeyToKeyboardBuffer(0x0B);
@@ -1705,7 +1715,7 @@ static void IKBD_Cmd_ReportMouseThreshold(void)
  */
 static void IKBD_Cmd_ReportMouseScale(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseScale\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseScale\n");
 
 	IKBD_AddKeyToKeyboardBufferWithDelay(0xf6, 30000);
 	IKBD_AddKeyToKeyboardBuffer(0x0C);
@@ -1726,7 +1736,7 @@ static void IKBD_Cmd_ReportMouseScale(void)
  */
 static void IKBD_Cmd_ReportMouseVertical(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseVertical\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseVertical\n");
 
 	IKBD_AddKeyToKeyboardBufferWithDelay(0xf6, 30000);
 	if (KeyboardProcessor.Mouse.YAxis == -1)
@@ -1750,7 +1760,7 @@ static void IKBD_Cmd_ReportMouseVertical(void)
  */
 static void IKBD_Cmd_ReportMouseAvailability(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseAvailability\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReportMouseAvailability\n");
 
 	IKBD_AddKeyToKeyboardBufferWithDelay(0xf6, 30000);
 	if (KeyboardProcessor.MouseMode == AUTOMODE_OFF)
@@ -1774,7 +1784,7 @@ static void IKBD_Cmd_ReportMouseAvailability(void)
  */
 static void IKBD_Cmd_ReportJoystickMode(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReportJoystickMode\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReportJoystickMode\n");
 
 	IKBD_AddKeyToKeyboardBufferWithDelay(0xf6, 30000);
 	switch (KeyboardProcessor.JoystickMode)
@@ -1809,7 +1819,7 @@ static void IKBD_Cmd_ReportJoystickMode(void)
  */
 static void IKBD_Cmd_ReportJoystickAvailability(void)
 {
-	HATARI_TRACE(HATARI_TRACE_IKBD_CMDS, "IKBD_Cmd_ReportJoystickAvailability\n");
+	LOG_TRACE(TRACE_IKBD_CMDS, "IKBD_Cmd_ReportJoystickAvailability\n");
 
 	IKBD_AddKeyToKeyboardBufferWithDelay(0xf6, 30000);
 	if (KeyboardProcessor.JoystickMode == AUTOMODE_OFF)
@@ -1947,7 +1957,7 @@ void IKBD_InterruptHandler_MFP(void)
 	MFP_InputOnChannel(MFP_ACIA_BIT, MFP_IERB, &MFP_IPRB);
 
 	/* Clear flag so can allow another byte to be sent along serial line */
-	bByteInTransitToACIA = FALSE;
+	bByteInTransitToACIA = false;
 
 	/* If another key is waiting, start sending from keyboard processor now */
 	if (Keyboard.BufferHead!=Keyboard.BufferTail)
@@ -1970,7 +1980,7 @@ static void IKBD_SendByteToACIA(int nAciaCycles)
 		/* Send byte to ACIA */
 		Int_AddRelativeInterrupt(nAciaCycles, INT_CPU_CYCLE, INTERRUPT_IKBD_ACIA);
 		/* Set flag so only transmit one byte at a time */
-		bByteInTransitToACIA = TRUE;
+		bByteInTransitToACIA = true;
 	}
 }
 
@@ -2060,12 +2070,12 @@ void IKBD_KeyboardControl_ReadByte(void)
 	 * buffer empty bit for the next time the program polls the register */
 	ACIAStatusRegister |= ACIA_STATUS_REGISTER__TX_BUFFER_EMPTY;
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_IKBD_ACIA ) )
+	if (LOG_TRACE_LEVEL(TRACE_IKBD_ACIA))
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "ikbd read fffc00 ctrl=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-		                     IoMem[0xfffc00], nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("ikbd read fffc00 ctrl=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n",
+		                IoMem[0xfffc00], FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles);
 	}
 }
 
@@ -2087,12 +2097,12 @@ void IKBD_KeyboardData_ReadByte(void)
 
 	IoMem[0xfffc02] = IKBD_GetByteFromACIA();  /* Return our byte from keyboard processor */
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_IKBD_ACIA ) )
+	if (LOG_TRACE_LEVEL(TRACE_IKBD_ACIA))
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "ikbd read fffc02 data=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-		                     IoMem[0xfffc02], nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("ikbd read fffc02 data=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n",
+				IoMem[0xfffc02], FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles);
 	}
 }
 
@@ -2106,12 +2116,12 @@ void IKBD_KeyboardControl_WriteByte(void)
 	/* ACIA registers need wait states - but the value seems to vary in certain cases */
 	M68000_WaitState(8);
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_IKBD_ACIA ) )
+	if (LOG_TRACE_LEVEL(TRACE_IKBD_ACIA))
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "ikbd write fffc00 ctrl=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-		                     IoMem[0xfffc00], nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("ikbd write fffc00 ctrl=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n",
+				IoMem[0xfffc00], FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles);
 	}
 
 	/* [NP] We only handle reset of the ACIA */
@@ -2130,12 +2140,12 @@ void IKBD_KeyboardData_WriteByte(void)
 	/* ACIA registers need wait states - but the value seems to vary in certain cases */
 	M68000_WaitState(8);
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_IKBD_ACIA ) )
+	if (LOG_TRACE_LEVEL(TRACE_IKBD_ACIA))
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "ikbd write fffc02 data=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-		                     IoMem[0xfffc02], nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("ikbd write fffc02 data=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n",
+				IoMem[0xfffc02], FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles);
 	}
 
 	IKBD_SendByteToKeyboardProcessor(IoMem[0xfffc02]);  /* Pass our byte to the keyboard processor */
@@ -2174,7 +2184,7 @@ void IKBD_KeyboardData_WriteByte(void)
  * for reading/writing to $fffc02 with ExeMainHandler_Read / ExeMainHandler_Write
  * (once the Execute command 0x22 is received).
  *
- * When using custom program (ExeMode==TRUE), we must ignore all keyboard/mouse/joystick
+ * When using custom program (ExeMode==true), we must ignore all keyboard/mouse/joystick
  * events sent to IKBD_AddKeyToKeyboardBuffer. Only our functions can add bytes
  * to the keyboard buffer.
  *
@@ -2211,8 +2221,8 @@ static void IKBD_LoadMemoryByte ( Uint8 aciabyte )
 
 		if ( i < sizeof ( CustomCodeDefinitions ) / sizeof ( CustomCodeDefinitions[0] ) )	/* found */
 		{
-			HATARI_TRACE ( HATARI_TRACE_IKBD_EXEC, "ikbd loadmemory %d bytes crc=0x%x matches <%s>\n" ,
-				MemoryLoadNbBytesTotal , MemoryLoadCrc , CustomCodeDefinitions[ i ].Name );
+			LOG_TRACE(TRACE_IKBD_EXEC, "ikbd loadmemory %d bytes crc=0x%x matches <%s>\n",
+				  MemoryLoadNbBytesTotal, MemoryLoadCrc, CustomCodeDefinitions[ i ].Name);
 
 			crc32_reset ( &MemoryLoadCrc );
 			MemoryExeNbBytes = 0;
@@ -2222,8 +2232,8 @@ static void IKBD_LoadMemoryByte ( Uint8 aciabyte )
 
 		else							/* unknown code uploaded to ikbd RAM */
 		{
-			HATARI_TRACE ( HATARI_TRACE_IKBD_EXEC, "ikbd loadmemory %d bytes crc=0x%x : unknown code\n" ,
-				MemoryLoadNbBytesTotal , MemoryLoadCrc );
+			LOG_TRACE(TRACE_IKBD_EXEC, "ikbd loadmemory %d bytes crc=0x%x : unknown code\n",
+				  MemoryLoadNbBytesTotal, MemoryLoadCrc);
 
 			pIKBD_CustomCodeHandler_Read = NULL;
 			pIKBD_CustomCodeHandler_Write = NULL;
@@ -2249,8 +2259,8 @@ static void IKBD_CustomCodeHandler_CommonBoot ( Uint8 aciabyte )
 	crc32_add_byte ( &MemoryLoadCrc , aciabyte );
 	MemoryExeNbBytes++;
 
-	HATARI_TRACE ( HATARI_TRACE_IKBD_EXEC, "ikbd custom exe common boot write 0x%02x count %d crc=0x%x\n" ,
-		aciabyte , MemoryExeNbBytes , MemoryLoadCrc );
+	LOG_TRACE(TRACE_IKBD_EXEC, "ikbd custom exe common boot write 0x%02x count %d crc=0x%x\n",
+	          aciabyte, MemoryExeNbBytes, MemoryLoadCrc);
 
 	/* Search for a match amongst the known custom routines */
 	for ( i = 0 ; i < sizeof ( CustomCodeDefinitions ) / sizeof ( CustomCodeDefinitions[0] ) ; i++ )
@@ -2260,8 +2270,8 @@ static void IKBD_CustomCodeHandler_CommonBoot ( Uint8 aciabyte )
 
 	if ( i < sizeof ( CustomCodeDefinitions ) / sizeof ( CustomCodeDefinitions[0] ) )	/* found */
 	{
-		HATARI_TRACE ( HATARI_TRACE_IKBD_EXEC, "ikbd custom exe common boot, uploaded code matches <%s>\n" ,
-			CustomCodeDefinitions[ i ].Name );
+		LOG_TRACE(TRACE_IKBD_EXEC, "ikbd custom exe common boot, uploaded code matches <%s>\n",
+			  CustomCodeDefinitions[i].Name);
 
 		pIKBD_CustomCodeHandler_Read = CustomCodeDefinitions[ i ].ExeMainHandler_Read;
 		pIKBD_CustomCodeHandler_Write = CustomCodeDefinitions[ i ].ExeMainHandler_Write;
