@@ -8,13 +8,14 @@
 #ifndef HATARI_CONFIGURATION_H
 #define HATARI_CONFIGURATION_H
 
-/* Logging */
+/* Logging and debugging */
 typedef struct
 {
   char sLogFileName[FILENAME_MAX];
   char sTraceFileName[FILENAME_MAX];
   int nTextLogLevel;
   int nAlertDlgLogLevel;
+  int nNumberBase;
   bool bConfirmQuit;
 } CNF_LOG;
 
@@ -28,17 +29,10 @@ typedef struct
 
 
 /* Sound configuration */
-typedef enum
-{
-  PLAYBACK_LOW,
-  PLAYBACK_MEDIUM,
-  PLAYBACK_HIGH
-} SOUND_QUALITY;
-
 typedef struct
 {
   bool bEnableSound;
-  SOUND_QUALITY nPlaybackQuality;
+  int nPlaybackFreq;
   char szYMCaptureFileName[FILENAME_MAX];
 } CNF_SOUND;
 
@@ -82,6 +76,7 @@ typedef enum {
   SHORTCUT_RECANIM,
   SHORTCUT_RECSOUND,
   SHORTCUT_SOUND,
+  SHORTCUT_DEBUG,
   SHORTCUT_PAUSE,
   SHORTCUT_QUIT,
   SHORTCUT_LOADMEM,
@@ -119,6 +114,7 @@ typedef struct
 {
   JOYSTICKMODE nJoystickMode;
   bool bEnableAutoFire;
+  bool bEnableJumpOnFire2;
   int nJoyId;
   int nKeyCodeUp, nKeyCodeDown, nKeyCodeLeft, nKeyCodeRight, nKeyCodeFire;
 } JOYSTICK;
@@ -145,6 +141,7 @@ typedef enum
 typedef struct
 {
   bool bAutoInsertDiskB;
+  bool bSlowFloppy;                  /* true to slow down FDC emulation */
   WRITEPROTECTION nWriteProtection;
   char szDiskZipPath[MAX_FLOPPYDRIVES][FILENAME_MAX];
   char szDiskFileName[MAX_FLOPPYDRIVES][FILENAME_MAX];
@@ -153,7 +150,7 @@ typedef struct
 
 
 /* Hard drives configuration */
-#define MAX_HARDDRIVES  1
+#define MAX_HARDDRIVES  23
 
 typedef enum
 {
@@ -268,7 +265,6 @@ typedef struct
   DSPTYPE nDSPType;               /* how to "emulate" DSP */
   bool bRealTimeClock;
   bool bPatchTimerD;
-  bool bSlowFDC;                  /* TRUE to slow down FDC emulation */
   bool bFastForward;
 } CNF_SYSTEM;
 
