@@ -16,7 +16,8 @@ extern void Dialog_AboutDlg(void);
 extern int DlgAlert_Notice(const char *text);
 extern int DlgAlert_Query(const char *text);
 extern void Dialog_DeviceDlg(void);
-extern void Dialog_DiskDlg(void);
+extern void DlgFloppy_Main(void);
+extern void DlgHardDisk_Main(void);
 extern void Dialog_JoyDlg(void);
 extern void Dialog_KeyboardDlg(void);
 extern bool Dialog_MemDlg(void);
