@@ -11,8 +11,9 @@
 
 /* Name and version for window title: */
 //#define PROG_NAME "Hatari devel (" __DATE__ ")"
-#define PROG_NAME "Hatari v1.2.0"
+#define PROG_NAME "Hatari v1.3.1"
 
+#include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -23,9 +24,12 @@
 #include <SDL_types.h>
 #include <stdbool.h>
 
-#ifndef FALSE
-#define FALSE false
-#define TRUE  true
+#if __GNUC__ >= 3
+# define likely(x)      __builtin_expect (!!(x), 1)
+# define unlikely(x)    __builtin_expect (!!(x), 0)
+#else
+# define likely(x)      (x)
+# define unlikely(x)    (x)
 #endif
 
 #ifdef WIN32
@@ -36,6 +40,7 @@
 
 #define CALL_VAR(func)  { ((void(*)(void))func)(); }
 
+#define ARRAYSIZE(x) (int)(sizeof(x)/sizeof(x[0]))
 
 /* 68000 operand sizes */
 #define SIZE_BYTE  1
@@ -44,7 +49,7 @@
 
 
 extern bool bQuitProgram;
-extern bool bEnableDebug;
+extern Uint32 nRunVBLs;
 
 extern void Main_MemorySnapShot_Capture(bool bSave);
 extern bool Main_PauseEmulation(bool visualize);
