@@ -5,7 +5,7 @@
   your option any later version. Read the file gpl.txt for details.
 */
 
-extern BOOL MSA_FileNameIsMSA(char *pszFileName, BOOL bAllowGZ);
+extern bool MSA_FileNameIsMSA(char *pszFileName, bool bAllowGZ);
 extern Uint8 *MSA_UnCompress(Uint8 *pMSAFile, long *pImageSize);
 extern Uint8 *MSA_ReadDisk(char *pszFileName, long *pImageSize);
-extern BOOL MSA_WriteDisk(char *pszFileName, Uint8 *pBuffer, int ImageSize);
+extern bool MSA_WriteDisk(char *pszFileName, Uint8 *pBuffer, int ImageSize);
