@@ -14,10 +14,12 @@
 # include <strings.h>
 #endif
 
-char *Str_Trim(char *buffer);
-char *Str_ToUpper(char *pString);
-char *Str_ToLower(char *pString);
-char *Str_Trunc(char *str);
-bool Str_IsHex(const char *str);
+extern char *Str_Trim(char *buffer);
+extern char *Str_ToUpper(char *pString);
+extern char *Str_ToLower(char *pString);
+extern char *Str_Trunc(char *str);
+extern bool Str_IsHex(const char *str);
+extern bool Str_GetNumber(const char *value, Uint32 *number);
+extern int Str_ParseRange(char *str, Uint32 *lower, Uint32 *upper);
 
 #endif  /* HATARI_STR_H */
