@@ -8,10 +8,10 @@
 #ifndef HATARI_WAVFORMAT_H
 #define HATARI_WAVFORMAT_H
 
-extern BOOL bRecordingWav;
+extern bool bRecordingWav;
 
-extern BOOL WAVFormat_OpenFile(char *pszWavFileName);
+extern bool WAVFormat_OpenFile(char *pszWavFileName);
 extern void WAVFormat_CloseFile(void);
-extern void WAVFormat_Update(Sint8 *pSamples, int Index, int Length);
+extern void WAVFormat_Update(Sint16 pSamples[][2], int Index, int Length);
 
 #endif
