@@ -10,8 +10,8 @@
  * to the error log file and/or displays them in alert dialog boxes.
  *
  * It can also dynamically output trace messages, based on the content
- * of HatariTraceFlags. Multiple trace levels can be set at once, by setting
- * the corresponding bits in HatariTraceFlags
+ * of LogTraceFlags. Multiple trace levels can be set at once, by setting
+ * the corresponding bits in LogTraceFlags.
  */
 const char Log_fileid[] = "Hatari log.c : " __DATE__ " " __TIME__;
 
@@ -34,57 +34,62 @@ struct {
 	const char *Name;
 }
 TraceOptions[] = {
-	{ HATARI_TRACE_VIDEO_SYNC	, "video_sync" } ,
-	{ HATARI_TRACE_VIDEO_RES	, "video_res" } ,
-	{ HATARI_TRACE_VIDEO_COLOR	, "video_color" } ,
-	{ HATARI_TRACE_VIDEO_BORDER_V	, "video_border_v" } ,
-	{ HATARI_TRACE_VIDEO_BORDER_H	, "video_border_h" } ,
-	{ HATARI_TRACE_VIDEO_ADDR	, "video_addr" } ,
-	{ HATARI_TRACE_VIDEO_HBL	, "video_hbl" } ,
-	{ HATARI_TRACE_VIDEO_VBL	, "video_vbl" } ,
-	{ HATARI_TRACE_VIDEO_STE	, "video_ste" } ,
-	{ HATARI_TRACE_VIDEO_ALL	, "video_all" } ,
+	{ TRACE_NONE		 , "none" },
 
-	{ HATARI_TRACE_MFP_EXCEPTION	, "mfp_exception" } ,
-	{ HATARI_TRACE_MFP_START	, "mfp_start" } ,
-	{ HATARI_TRACE_MFP_READ		, "mfp_read" } ,
-	{ HATARI_TRACE_MFP_WRITE	, "mfp_write" } ,
-	{ HATARI_TRACE_MFP_ALL		, "mfp_all" } ,
+	{ TRACE_VIDEO_SYNC	 , "video_sync" } ,
+	{ TRACE_VIDEO_RES	 , "video_res" } ,
+	{ TRACE_VIDEO_COLOR	 , "video_color" } ,
+	{ TRACE_VIDEO_BORDER_V   , "video_border_v" } ,
+	{ TRACE_VIDEO_BORDER_H   , "video_border_h" } ,
+	{ TRACE_VIDEO_ADDR	 , "video_addr" } ,
+	{ TRACE_VIDEO_HBL	 , "video_hbl" } ,
+	{ TRACE_VIDEO_VBL	 , "video_vbl" } ,
+	{ TRACE_VIDEO_STE	 , "video_ste" } ,
+	{ TRACE_VIDEO_ALL	 , "video_all" } ,
 
-	{ HATARI_TRACE_PSG_READ		, "psg_read" } ,
-	{ HATARI_TRACE_PSG_WRITE	, "psg_write" } ,
-	{ HATARI_TRACE_PSG_ALL		, "psg_all" } ,
+	{ TRACE_MFP_EXCEPTION	 , "mfp_exception" } ,
+	{ TRACE_MFP_START	 , "mfp_start" } ,
+	{ TRACE_MFP_READ	 , "mfp_read" } ,
+	{ TRACE_MFP_WRITE	 , "mfp_write" } ,
+	{ TRACE_MFP_ALL 	 , "mfp_all" } ,
 
-	{ HATARI_TRACE_CPU_PAIRING	, "cpu_pairing" } ,
-	{ HATARI_TRACE_CPU_DISASM	, "cpu_disasm" } ,
-	{ HATARI_TRACE_CPU_EXCEPTION	, "cpu_exception" } ,
-	{ HATARI_TRACE_CPU_ALL		, "cpu_all" } ,
+	{ TRACE_PSG_READ	 , "psg_read" } ,
+	{ TRACE_PSG_WRITE	 , "psg_write" } ,
+	{ TRACE_PSG_ALL 	 , "psg_all" } ,
 
-	{ HATARI_TRACE_INT		, "int" } ,
+	{ TRACE_CPU_PAIRING	 , "cpu_pairing" } ,
+	{ TRACE_CPU_DISASM	 , "cpu_disasm" } ,
+	{ TRACE_CPU_EXCEPTION	 , "cpu_exception" } ,
+	{ TRACE_CPU_ALL 	 , "cpu_all" } ,
 
-	{ HATARI_TRACE_FDC		, "fdc" } ,
+	{ TRACE_INT		 , "int" } ,
 
-	{ HATARI_TRACE_IKBD_CMDS	, "ikbd_cmds" } ,
-	{ HATARI_TRACE_IKBD_ACIA	, "ikbd_acia" } ,
-	{ HATARI_TRACE_IKBD_EXEC	, "ikbd_exec" } ,
-	{ HATARI_TRACE_IKBD_ALL		, "ikbd_all" } ,
+	{ TRACE_FDC		 , "fdc" } ,
 
-	{ HATARI_TRACE_BLITTER		, "blitter" } ,
+	{ TRACE_IKBD_CMDS	 , "ikbd_cmds" } ,
+	{ TRACE_IKBD_ACIA	 , "ikbd_acia" } ,
+	{ TRACE_IKBD_EXEC	 , "ikbd_exec" } ,
+	{ TRACE_IKBD_ALL	 , "ikbd_all" } ,
 
-	{ HATARI_TRACE_OS_BIOS		, "bios" },
-	{ HATARI_TRACE_OS_XBIOS		, "xbios" },
-	{ HATARI_TRACE_OS_GEMDOS	, "gemdos" },
-	{ HATARI_TRACE_OS_VDI		, "vdi" },
-	{ HATARI_TRACE_OS_ALL		, "os_all" } ,
+	{ TRACE_BLITTER 	 , "blitter" } ,
 
-	{ HATARI_TRACE_IOMEM_RD 	, "io_read" } ,
-	{ HATARI_TRACE_IOMEM_WR 	, "io_write" } ,
+	{ TRACE_OS_BIOS 	 , "bios" },
+	{ TRACE_OS_XBIOS	 , "xbios" },
+	{ TRACE_OS_GEMDOS	 , "gemdos" },
+	{ TRACE_OS_VDI  	 , "vdi" },
+	{ TRACE_OS_ALL  	 , "os_all" } ,
 
-	{ HATARI_TRACE_ALL		, "all" }
+	{ TRACE_IOMEM_RD	 , "io_read" } ,
+	{ TRACE_IOMEM_WR	 , "io_write" } ,
+	{ TRACE_IOMEM_ALL	 , "io_all" } ,
+
+	{ TRACE_DMASND  	 , "dmasound" } ,
+
+	{ TRACE_ALL		 , "all" }
 };
 
 
-Uint32	HatariTraceFlags = HATARI_TRACE_NONE;
+Uint32	LogTraceFlags = TRACE_NONE;
 FILE *TraceFile = NULL;
 
 static FILE *hLogFile = NULL;
@@ -216,10 +221,13 @@ LOGTYPE Log_ParseOptions(const char *arg)
  * corresponding trace flag is turned on.
  * If the string is prefixed with a '-',
  * corresponding trace flag is turned off.
- * Result is stored in HatariTraceFlags.
+ * Result is stored in LogTraceFlags.
+ * Return error string or NULL for success.
  */
-bool Log_SetTraceOptions (const char *OptionsStr)
+const char* Log_SetTraceOptions (const char *OptionsStr)
 {
+#if ENABLE_TRACING
+
 	char *OptionsCopy;
 	char *cur, *sep;
 	int i;
@@ -239,25 +247,19 @@ bool Log_SetTraceOptions (const char *OptionsStr)
 		fprintf(stderr, "Multiple trace levels can be separated by ','\n");
 		fprintf(stderr, "Levels can be prefixed by '+' or '-' to be mixed.\n");
 		fprintf(stderr, "Giving just trace level 'none' disables all traces.\n\n");
-		return FALSE;
+		return NULL;
 	}
-
-#ifndef HATARI_TRACE_ACTIVATED
-	fprintf(stderr, "\nError: Trace option has not been activated during compile time.\n");
-	return FALSE;
-#endif
 	
-	HatariTraceFlags = HATARI_TRACE_NONE;
+	LogTraceFlags = TRACE_NONE;
 	if (strcmp (OptionsStr, "none") == 0)
 	{
-		return TRUE;
+		return NULL;
 	}
 	
 	OptionsCopy = strdup(OptionsStr);
 	if (!OptionsCopy)
 	{
-		fprintf(stderr, "strdup error in ParseTraceOptions\n");
-		return FALSE;
+		return "strdup error in ParseTraceOptions";
 	}
 	
 	cur = OptionsCopy;
@@ -282,22 +284,26 @@ bool Log_SetTraceOptions (const char *OptionsStr)
 		if (i < MaxOptions)		/* option found */
 		{
 			if (Mode == 0)
-				HatariTraceFlags |= TraceOptions[i].Level;
+				LogTraceFlags |= TraceOptions[i].Level;
 			else
-				HatariTraceFlags &= (~TraceOptions[i].Level);
+				LogTraceFlags &= (~TraceOptions[i].Level);
 		}
 		else
 		{
-			fprintf(stderr, "unknown trace option %s\n", cur);
+			fprintf(stderr, "Unknown trace type '%s'\n", cur);
 			free(OptionsCopy);
-			return FALSE;
+			return "Unknown trace type.";
 		}
 		
 		cur = sep;
 	}
 	
-	//fprintf(stderr, "trace parse <%x>\n", HatariTraceFlags);
+	//fprintf(stderr, "trace parse <%x>\n", LogTraceFlags);
 	
 	free (OptionsCopy);
-	return TRUE;
+	return NULL;
+
+#else	/* ENABLE_TRACING */
+	return "Hatari has been compiled without ENABLE_TRACING!";
+#endif
 }
