@@ -87,9 +87,10 @@
 /* 2008/10/16	[NP]	No need to set data reg to 255 when decrementing a data reg that*/
 /*			was 0, this is already what is implicitly done, because data	*/
 /*			reg for timer A/B is Uint8 (revert 2008/10/04 changes).		*/
-/* 2008/12/11	[NP]	In MFP_CheckPendingInterrupts(), returns TRUE or FALSE instead	*/
+/* 2008/12/11	[NP]	In MFP_CheckPendingInterrupts(), returns true or false instead	*/
 /*			of void, depending on whether at least one MFP interrupt was	*/
 /*			allowed or not.							*/
+/* 2009/03/28	[NP]	Handle bit 3 of AER for timer B (fix Seven Gates Of Jambala).	*/
 
 
 const char MFP_fileid[] = "Hatari mfp.c : " __DATE__ " " __TIME__;
@@ -161,12 +162,12 @@ static int TimerDClockCycles=0;
 /* If a timer is stopped then restarted later without writing to the data register, */
 /* we must resume the timer from where we left in the interrupts table, instead of */
 /* computing a new number of clock cycles to restart the interrupt. */
-static bool TimerACanResume = FALSE;
-static bool TimerBCanResume = FALSE;
-static bool TimerCCanResume = FALSE;
-static bool TimerDCanResume = FALSE;
+static bool TimerACanResume = false;
+static bool TimerBCanResume = false;
+static bool TimerCCanResume = false;
+static bool TimerDCanResume = false;
 
-bool bAppliedTimerDPatch;           /* TRUE if the Timer-D patch has been applied */
+bool bAppliedTimerDPatch;           /* true if the Timer-D patch has been applied */
 static int nTimerDFakeValue;        /* Faked Timer-D data register for the Timer-D patch */
 
 static int PendingCyclesOver = 0;   /* >= 0 value, used to "loop" a timer when data counter reaches 0 */
@@ -199,7 +200,7 @@ void MFP_Reset(void)
 {
 	/* Reset MFP internal variables */
 
-	bAppliedTimerDPatch = FALSE;
+	bAppliedTimerDPatch = false;
 
 	MFP_GPIP = 0xff;
 	MFP_AER = MFP_DDR = 0;
@@ -277,12 +278,12 @@ static void MFP_Exception(int Interrupt)
 	Vec = (unsigned int)(MFP_VR&0xf0)<<2;
 	Vec += Interrupt<<2;
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_EXCEPTION ) )
+	if (LOG_TRACE_LEVEL(TRACE_MFP_EXCEPTION))
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp excep int=%d vec=0x%x new_pc=0x%x video_cyc=%d %d@%d\n" ,
-			Interrupt, Vec, STMemory_ReadLong ( Vec ), nFrameCycles, nLineCycles, nHBL );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp excep int=%d vec=0x%x new_pc=0x%x video_cyc=%d %d@%d\n" ,
+			Interrupt, Vec, STMemory_ReadLong ( Vec ), FrameCycles, LineCycles, HblCounterVideo );
 	}
 
 	M68000_Exception ( Vec , M68000_EXCEPTION_SRC_INT_MFP );
@@ -311,7 +312,8 @@ static void MFP_UpdateFlags(void)
 
 /*-----------------------------------------------------------------------*/
 /**
- * Test interrupt request to see if can cause exception,return TRUE if pass vector
+ * Test interrupt request to see if can cause exception.
+ * @return true if pass vector
  */
 static bool MFP_InterruptRequest(int nMfpException, Uint8 Bit, Uint8 *pPendingReg, Uint8 MaskRegister,
                                  Uint8 PriorityMaskLow, Uint8 PriorityMaskHigh, Uint8 *pInServiceReg)
@@ -336,12 +338,12 @@ static bool MFP_InterruptRequest(int nMfpException, Uint8 Bit, Uint8 *pPendingRe
 
 				/* Call interrupt, adds in base (default 0x100) */
 				MFP_Exception(nMfpException);
-				return TRUE;
+				return true;
 			}
 		}
 	}
 
-	return FALSE;
+	return false;
 }
 
 
@@ -349,7 +351,7 @@ static bool MFP_InterruptRequest(int nMfpException, Uint8 Bit, Uint8 *pPendingRe
 /**
  * Check 'pending' registers to see if any MFP interrupts need servicing.
  * Request interrupt if necessary.
- * Return TRUE if at least one MFP interrupt was allowed, else return FALSE.
+ * @return true if at least one MFP interrupt was allowed, else return false.
  */
 bool MFP_CheckPendingInterrupts(void)
 {
@@ -360,11 +362,11 @@ bool MFP_CheckPendingInterrupts(void)
 	{
 		/* Should never get here, but if do just clear flag (see 'MFP_UpdateFlags') */
 		M68000_UnsetSpecial(SPCFLAG_MFP);
-		return FALSE;
+		return false;
 	}
 
 
-	InterruptPossible = FALSE;
+	InterruptPossible = false;
 
 	if (MFP_IPRA & MFP_TIMER_GPIP7_BIT)   /* Check MFP GPIP7 interrupt (bit 7) */
 		InterruptPossible |= MFP_InterruptRequest(MFP_EXCEPT_GPIP7, MFP_TIMER_GPIP7_BIT, &MFP_IPRA, MFP_IMRA, 0x80, 0x00, &MFP_ISRA);
@@ -454,6 +456,8 @@ void MFP_TimerA_EventCount_Interrupt(void)
  */
 void MFP_TimerB_EventCount_Interrupt(void)
 {
+	LOG_TRACE(TRACE_VIDEO_HBL , "mfp/video timer B new event count %d\n" , MFP_TB_MAINCOUNTER-1 );
+
 	if (MFP_TB_MAINCOUNTER == 1)			/* Timer expired? If so, generate interrupt */
 	{
 		MFP_TB_MAINCOUNTER = MFP_TBDR;		/* Reload timer from data register */
@@ -478,7 +482,7 @@ void MFP_TimerB_EventCount_Interrupt(void)
 /**
  * Start Timer A or B - EventCount mode is done in HBL handler to time correctly
  */
-static int MFP_StartTimer_AB(Uint8 TimerControl, Uint16 TimerData, int Handler,
+static int MFP_StartTimer_AB(Uint8 TimerControl, Uint16 TimerData, interrupt_id Handler,
                              bool bFirstTimer, bool *pTimerCanResume)
 {
 	int TimerClockCycles = 0;
@@ -494,14 +498,14 @@ static int MFP_StartTimer_AB(Uint8 TimerControl, Uint16 TimerData, int Handler,
 			TimerData = 256;
 		TimerClockCycles = MFP_REG_TO_CYCLES ( TimerData, TimerControl );
 
-		if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_START ) )
+		if (LOG_TRACE_LEVEL(TRACE_MFP_START))
 		{
-			int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-			int nLineCycles = nFrameCycles % nCyclesPerLine;
-			HATARI_TRACE_PRINT ( "mfp start AB handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n" ,
-			                     Handler, TimerData, TimerControl, TimerClockCycles, PendingCyclesOver,
-			                     nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles,
-			                     bFirstTimer?"true":"false" , *pTimerCanResume?"true":"false" );
+			int FrameCycles, HblCounterVideo, LineCycles;
+			Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+			LOG_TRACE_PRINT("mfp start AB handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n",
+			                Handler, TimerData, TimerControl, TimerClockCycles, PendingCyclesOver,
+			                FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles,
+			                bFirstTimer?"true":"false", *pTimerCanResume?"true":"false");
 		}
 
 		/* And add to our internal interrupt list, if timer cycles is zero
@@ -509,7 +513,7 @@ static int MFP_StartTimer_AB(Uint8 TimerControl, Uint16 TimerData, int Handler,
 		Int_RemovePendingInterrupt(Handler);
 		if (TimerClockCycles)
 		{
-			if ( ( *pTimerCanResume == TRUE ) && ( bFirstTimer == TRUE ) )	/* we can't resume if the timer is auto restarting after an interrupt */
+			if ((*pTimerCanResume == true) && (bFirstTimer == true))	/* we can't resume if the timer is auto restarting after an interrupt */
 			{
 				Int_ResumeStoppedInterrupt ( Handler );
 			}
@@ -531,21 +535,21 @@ static int MFP_StartTimer_AB(Uint8 TimerControl, Uint16 TimerData, int Handler,
 					Int_AddRelativeInterruptWithOffset(TimerClockCycles, INT_MFP_CYCLE, Handler, -PendingCyclesOver);
 				}
 
-				*pTimerCanResume = TRUE;		/* timer was set, resume is possible if stop/start it later */
+				*pTimerCanResume = true;		/* timer was set, resume is possible if stop/start it later */
 			}
 		}
 
 		else	/* Ctrl was 0 -> timer is stopped */
 		{
 			/* do nothing, only print some traces */
-			if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_START ) )
+			if (LOG_TRACE_LEVEL(TRACE_MFP_START))
 			{
-				int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-				int nLineCycles = nFrameCycles % nCyclesPerLine;
-				HATARI_TRACE_PRINT ( "mfp stop AB handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n" ,
-			                     Handler, TimerData, TimerControl, TimerClockCycles, PendingCyclesOver,
-			                     nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles,
-			                     bFirstTimer?"true":"false" , *pTimerCanResume?"true":"false" );
+				int FrameCycles, HblCounterVideo, LineCycles;
+				Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+				LOG_TRACE_PRINT("mfp stop AB handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n",
+				                Handler, TimerData, TimerControl, TimerClockCycles, PendingCyclesOver,
+				                FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles,
+				                bFirstTimer?"true":"false", *pTimerCanResume?"true":"false");
 			}
 		}
 	}
@@ -558,16 +562,20 @@ static int MFP_StartTimer_AB(Uint8 TimerControl, Uint16 TimerData, int Handler,
 
 	if (TimerControl == 8 )				/* event count mode */
 	{
-		/* do nothing, only print some traces */
-
-		if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_START ) )
+		if ( Handler == INTERRUPT_MFP_TIMERB )		/* we're starting timer B event count mode */
 		{
-			int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-			int nLineCycles = nFrameCycles % nCyclesPerLine;
-			HATARI_TRACE_PRINT ( "mfp start AB handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n" ,
-			                     Handler, TimerData, TimerControl, TimerClockCycles, PendingCyclesOver,
-			                     nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles,
-			                     bFirstTimer?"true":"false" , *pTimerCanResume?"true":"false" );
+			/* Store start cycle for handling interrupt in video.c */
+			TimerBEventCountCycleStart = Cycles_GetCounterOnWriteAccess(CYCLES_COUNTER_VIDEO);
+		}
+
+		if (LOG_TRACE_LEVEL(TRACE_MFP_START))
+		{
+			int FrameCycles, HblCounterVideo, LineCycles;
+			Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+			LOG_TRACE_PRINT("mfp start AB handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n",
+			                Handler, TimerData, TimerControl, TimerClockCycles, PendingCyclesOver,
+			                FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles,
+			                bFirstTimer?"true":"false", *pTimerCanResume?"true":"false");
 		}
 
 
@@ -581,7 +589,7 @@ static int MFP_StartTimer_AB(Uint8 TimerControl, Uint16 TimerData, int Handler,
 /**
  * Start Timer C or D
  */
-static int MFP_StartTimer_CD(Uint8 TimerControl, Uint16 TimerData, int Handler,
+static int MFP_StartTimer_CD(Uint8 TimerControl, Uint16 TimerData, interrupt_id Handler,
                              bool bFirstTimer, bool *pTimerCanResume)
 {
 	int TimerClockCycles = 0;
@@ -596,13 +604,13 @@ static int MFP_StartTimer_CD(Uint8 TimerControl, Uint16 TimerData, int Handler,
 			TimerData = 256;
 		TimerClockCycles = MFP_REG_TO_CYCLES ( TimerData, TimerControl );
 
-		if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_START ) )
+		if ( LOG_TRACE_LEVEL( TRACE_MFP_START ) )
 		{
-			int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-			int nLineCycles = nFrameCycles % nCyclesPerLine;
-			HATARI_TRACE_PRINT ( "mfp start CD handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n" ,
+			int FrameCycles, HblCounterVideo, LineCycles;
+			Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+			LOG_TRACE_PRINT("mfp start CD handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n" ,
 			                     Handler, TimerData, TimerControl, TimerClockCycles, PendingCyclesOver,
-			                     nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles,
+			                     FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles,
 			                     bFirstTimer?"true":"false" , *pTimerCanResume?"true":"false" );
 		}
 
@@ -611,7 +619,7 @@ static int MFP_StartTimer_CD(Uint8 TimerControl, Uint16 TimerData, int Handler,
 		Int_RemovePendingInterrupt(Handler);
 		if (TimerClockCycles)
 		{
-			if ( ( *pTimerCanResume == TRUE ) && ( bFirstTimer == TRUE ) )	/* we can't resume if the timer is auto restarting after an interrupt */
+			if ((*pTimerCanResume == true) && (bFirstTimer == true))	/* we can't resume if the timer is auto restarting after an interrupt */
 			{
 				Int_ResumeStoppedInterrupt ( Handler );
 			}
@@ -633,20 +641,20 @@ static int MFP_StartTimer_CD(Uint8 TimerControl, Uint16 TimerData, int Handler,
 					Int_AddRelativeInterruptWithOffset(TimerClockCycles, INT_MFP_CYCLE, Handler, -PendingCyclesOver);
 				}
 
-				*pTimerCanResume = TRUE;		/* timer was set, resume is possible if stop/start it later */
+				*pTimerCanResume = true;		/* timer was set, resume is possible if stop/start it later */
 			}
 		}
 	}
 
 	else	/* timer control is 0 */
 	{
-		if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_START ) )
+		if ( LOG_TRACE_LEVEL( TRACE_MFP_START ) )
 		{
-			int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-			int nLineCycles = nFrameCycles % nCyclesPerLine;
-			HATARI_TRACE_PRINT ( "mfp stop CD handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n" ,
+			int FrameCycles, HblCounterVideo, LineCycles;
+			Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+			LOG_TRACE_PRINT("mfp stop CD handler=%d data=%d ctrl=%d timer_cyc=%d pending_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d first=%s resume=%s\n" ,
 			                     Handler, TimerData, TimerControl, TimerClockCycles, PendingCyclesOver,
-			                     nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles,
+			                     FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles,
 			                     bFirstTimer?"true":"false" , *pTimerCanResume?"true":"false" );
 		}
 
@@ -662,7 +670,7 @@ static int MFP_StartTimer_CD(Uint8 TimerControl, Uint16 TimerData, int Handler,
 /**
  * Read Timer A or B - If in EventCount MainCounter already has correct value
  */
-static Uint8 MFP_ReadTimer_AB(Uint8 TimerControl, Uint8 MainCounter, int TimerCycles, int Handler, bool TimerIsStopping)
+static Uint8 MFP_ReadTimer_AB(Uint8 TimerControl, Uint8 MainCounter, int TimerCycles, interrupt_id Handler, bool TimerIsStopping)
 {
 //	int TimerCyclesPassed;
 
@@ -684,18 +692,18 @@ static Uint8 MFP_ReadTimer_AB(Uint8 TimerControl, Uint8 MainCounter, int TimerCy
 		if ( Int_FindCyclesPassed ( Handler, INT_MFP_CYCLE ) < MFP_REG_TO_CYCLES ( 1 , TimerControl ) )
 		{
 			MainCounter = 0;			/* internal mfp counter becomes 0 (=256) */
-			HATARI_TRACE ( HATARI_TRACE_MFP_READ , "mfp read AB handler=%d stopping timer while data reg between 1 and 0 : forcing data to 256\n" ,
+			LOG_TRACE(TRACE_MFP_READ , "mfp read AB handler=%d stopping timer while data reg between 1 and 0 : forcing data to 256\n" ,
 					Handler );
 		}
 	}
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_READ ) )
+	if ( LOG_TRACE_LEVEL( TRACE_MFP_READ ) )
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp read AB handler=%d data=%d ctrl=%d timer_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n" ,
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp read AB handler=%d data=%d ctrl=%d timer_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n" ,
 		                     Handler, MainCounter, TimerControl, TimerCycles,
-		                     nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		                     FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 	}
 
 	return MainCounter;
@@ -706,7 +714,7 @@ static Uint8 MFP_ReadTimer_AB(Uint8 TimerControl, Uint8 MainCounter, int TimerCy
 /**
  * Read Timer C or D
  */
-static Uint8 MFP_ReadTimerCD(Uint8 TimerControl, Uint8 TimerData, Uint8 MainCounter, int TimerCycles, int Handler, bool TimerIsStopping)
+static Uint8 MFP_ReadTimerCD(Uint8 TimerControl, Uint8 TimerData, Uint8 MainCounter, int TimerCycles, interrupt_id Handler, bool TimerIsStopping)
 {
 //	int TimerCyclesPassed;
 
@@ -728,18 +736,18 @@ static Uint8 MFP_ReadTimerCD(Uint8 TimerControl, Uint8 TimerData, Uint8 MainCoun
 		if ( Int_FindCyclesPassed ( Handler, INT_MFP_CYCLE ) < MFP_REG_TO_CYCLES ( 1 , TimerControl ) )
 		{
 			MainCounter = 0;			/* internal mfp counter becomes 0 (=256) */
-			HATARI_TRACE ( HATARI_TRACE_MFP_READ , "mfp read CD handler=%d stopping timer while data reg between 1 and 0 : forcing data to 256\n" ,
+			LOG_TRACE(TRACE_MFP_READ , "mfp read CD handler=%d stopping timer while data reg between 1 and 0 : forcing data to 256\n" ,
 					Handler );
 		}
 	}
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_READ ) )
+	if ( LOG_TRACE_LEVEL( TRACE_MFP_READ ) )
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp read CD handler=%d data=%d ctrl=%d timer_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n" ,
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp read CD handler=%d data=%d ctrl=%d timer_cyc=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n" ,
 		                     Handler, MainCounter, TimerControl, TimerCycles,
-		                     nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		                     FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 	}
 
 	return MainCounter;
@@ -753,7 +761,7 @@ static Uint8 MFP_ReadTimerCD(Uint8 TimerControl, Uint8 TimerData, Uint8 MainCoun
 static void MFP_StartTimerA(void)
 {
 	TimerAClockCycles = MFP_StartTimer_AB(MFP_TACR, MFP_TA_MAINCOUNTER,
-	                                      INTERRUPT_MFP_TIMERA, TRUE, &TimerACanResume);
+	                                      INTERRUPT_MFP_TIMERA, true, &TimerACanResume);
 }
 
 
@@ -777,7 +785,7 @@ static void MFP_ReadTimerA(bool TimerIsStopping)
 static void MFP_StartTimerB(void)
 {
 	TimerBClockCycles = MFP_StartTimer_AB(MFP_TBCR, MFP_TB_MAINCOUNTER,
-	                                      INTERRUPT_MFP_TIMERB, TRUE, &TimerBCanResume);
+	                                      INTERRUPT_MFP_TIMERB, true, &TimerBCanResume);
 }
 
 
@@ -799,7 +807,7 @@ static void MFP_ReadTimerB(bool TimerIsStopping)
 static void MFP_StartTimerC(void)
 {
 	TimerCClockCycles = MFP_StartTimer_CD((MFP_TCDCR>>4)&7, MFP_TC_MAINCOUNTER,
-	                                      INTERRUPT_MFP_TIMERC , TRUE, &TimerCCanResume);
+	                                      INTERRUPT_MFP_TIMERC , true, &TimerCCanResume);
 }
 
 
@@ -821,7 +829,7 @@ static void MFP_ReadTimerC(bool TimerIsStopping)
 static void MFP_StartTimerD(void)
 {
 	TimerDClockCycles = MFP_StartTimer_CD(MFP_TCDCR&7, MFP_TD_MAINCOUNTER,
-	                                      INTERRUPT_MFP_TIMERD, TRUE, &TimerDCanResume);
+	                                      INTERRUPT_MFP_TIMERD, true, &TimerDCanResume);
 }
 
 
@@ -854,7 +862,7 @@ void MFP_InterruptHandler_TimerA(void)
 		MFP_InputOnChannel(MFP_TIMER_A_BIT, MFP_IERA, &MFP_IPRA);
 
 	/* Start next interrupt, if need one - from current cycle count */
-	TimerAClockCycles = MFP_StartTimer_AB(MFP_TACR, MFP_TADR, INTERRUPT_MFP_TIMERA, FALSE, &TimerACanResume);
+	TimerAClockCycles = MFP_StartTimer_AB(MFP_TACR, MFP_TADR, INTERRUPT_MFP_TIMERA, false, &TimerACanResume);
 }
 
 
@@ -876,7 +884,7 @@ void MFP_InterruptHandler_TimerB(void)
 		MFP_InputOnChannel(MFP_TIMER_B_BIT, MFP_IERA, &MFP_IPRA);
 
 	/* Start next interrupt, if need one - from current cycle count */
-	TimerBClockCycles = MFP_StartTimer_AB(MFP_TBCR, MFP_TBDR, INTERRUPT_MFP_TIMERB, FALSE, &TimerBCanResume);
+	TimerBClockCycles = MFP_StartTimer_AB(MFP_TBCR, MFP_TBDR, INTERRUPT_MFP_TIMERB, false, &TimerBCanResume);
 }
 
 
@@ -898,7 +906,7 @@ void MFP_InterruptHandler_TimerC(void)
 		MFP_InputOnChannel(MFP_TIMER_C_BIT, MFP_IERB, &MFP_IPRB);
 
 	/* Start next interrupt, if need one - from current cycle count */
-	TimerCClockCycles = MFP_StartTimer_CD((MFP_TCDCR>>4)&7, MFP_TCDR, INTERRUPT_MFP_TIMERC, FALSE, &TimerCCanResume);
+	TimerCClockCycles = MFP_StartTimer_CD((MFP_TCDCR>>4)&7, MFP_TCDR, INTERRUPT_MFP_TIMERC, false, &TimerCCanResume);
 }
 
 
@@ -920,7 +928,7 @@ void MFP_InterruptHandler_TimerD(void)
 		MFP_InputOnChannel(MFP_TIMER_D_BIT, MFP_IERB, &MFP_IPRB);
 
 	/* Start next interrupt, if need one - from current cycle count */
-	TimerDClockCycles = MFP_StartTimer_CD(MFP_TCDCR&7, MFP_TDDR, INTERRUPT_MFP_TIMERD, FALSE, &TimerDCanResume);
+	TimerDClockCycles = MFP_StartTimer_CD(MFP_TCDCR&7, MFP_TDDR, INTERRUPT_MFP_TIMERD, false, &TimerDCanResume);
 }
 
 
@@ -974,12 +982,12 @@ void MFP_GPIP_ReadByte(void)
 
 	IoMem[0xfffa01] = MFP_GPIP;
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_READ ) )
+	if ( LOG_TRACE_LEVEL( TRACE_MFP_READ ) )
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp read gpip fa01=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-			MFP_GPIP, nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp read gpip fa01=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
+			MFP_GPIP, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 	}
 }
 
@@ -1146,7 +1154,7 @@ void MFP_TimerAData_ReadByte(void)
 	M68000_WaitState(4);
 
 	if (MFP_TACR != 8)          		/* Is event count? Need to re-calculate counter */
-		MFP_ReadTimerA(FALSE);		/* Stores result in 'MFP_TA_MAINCOUNTER' */
+		MFP_ReadTimerA(false);		/* Stores result in 'MFP_TA_MAINCOUNTER' */
 
 	IoMem[0xfffa1f] = MFP_TA_MAINCOUNTER;
 }
@@ -1166,7 +1174,7 @@ void MFP_TimerBData_ReadByte(void)
 	{
 		/* Not event count mode, so handle as normal timer
 		 * and store result in 'MFP_TB_MAINCOUNTER' */
-		MFP_ReadTimerB(FALSE);
+		MFP_ReadTimerB(false);
 	}
 	else if (bUseVDIRes)
 	{
@@ -1177,11 +1185,12 @@ void MFP_TimerBData_ReadByte(void)
 	/* overlaps the horizontal video position where $fffa21 is changed */
 	else
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
+		int FrameCycles, HblCounterVideo;
 		int pos_start , pos_read;
 
 		/* Cycle position of the start of the current instruction */
-		pos_start = nFrameCycles % nCyclesPerLine;
+		//pos_start = nFrameCycles % nCyclesPerLine;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &pos_start );
 		/* Cycle position of the read for the current instruction (approximatively, we consider */
 		/* the read happens after 4 cycles (due to MFP wait states in that case)) */
 		/* This is quite a hack, but hard to do without proper 68000 read cycle emulation */
@@ -1197,8 +1206,8 @@ void MFP_TimerBData_ReadByte(void)
 		if ( (nHBL >= nStartHBL ) && ( nHBL < nEndHBL )	/* ensure display is ON and timer B can happen */
 			&& ( LineTimerBCycle > pos_start ) && ( LineTimerBCycle < pos_read ) )
 		{
-			HATARI_TRACE ( HATARI_TRACE_MFP_READ , "mfp read TB overlaps pos_start=%d TB_pos=%d pos_read=%d nHBL=%d \n",
-					pos_start, LineTimerBCycle, pos_read , nHBL );
+			LOG_TRACE(TRACE_MFP_READ , "mfp read TB overlaps pos_start=%d TB_pos=%d pos_read=%d nHBL=%d \n",
+					pos_start, LineTimerBCycle, pos_read , HblCounterVideo );
 
 			TB_count--;
 			if ( TB_count == 0 )			/* going from 1 to 0 : timer restart, reload data reg */
@@ -1210,8 +1219,8 @@ void MFP_TimerBData_ReadByte(void)
 */
 		}
 
-		HATARI_TRACE ( HATARI_TRACE_MFP_READ , "mfp read TB data=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n" ,
-					TB_count, nFrameCycles, pos_start, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		LOG_TRACE(TRACE_MFP_READ , "mfp read TB data=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n" ,
+					TB_count, FrameCycles, pos_start, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 		IoMem[0xfffa21] = TB_count;
 		return;
 	}
@@ -1227,7 +1236,7 @@ void MFP_TimerCData_ReadByte(void)
 {
 	M68000_WaitState(4);
 
-	MFP_ReadTimerC(FALSE);		/* Stores result in 'MFP_TC_MAINCOUNTER' */
+	MFP_ReadTimerC(false);		/* Stores result in 'MFP_TC_MAINCOUNTER' */
 
 	IoMem[0xfffa23] = MFP_TC_MAINCOUNTER;
 }
@@ -1249,7 +1258,7 @@ void MFP_TimerDData_ReadByte(void)
 	}
 	else
 	{
-		MFP_ReadTimerD(FALSE);	/* Stores result in 'MFP_TD_MAINCOUNTER' */
+		MFP_ReadTimerD(false);	/* Stores result in 'MFP_TD_MAINCOUNTER' */
 		IoMem[0xfffa25] = MFP_TD_MAINCOUNTER;
 	}
 }
@@ -1270,12 +1279,48 @@ void MFP_GPIP_WriteByte(void)
 
 /*-----------------------------------------------------------------------*/
 /**
- * Handle write to AER (0xfffa03).
+ * Handle write to AER (0xfffa03)
+ * Bit 3 of AER is linked to timer B in event count mode.
+ * If bit 3=0, timer B triggers on end of line when display goes off.
+ * If bit 3=1, timer B triggers on start of line when display goes on.
  */
 void MFP_ActiveEdge_WriteByte(void)
 {
+	int FrameCycles, HblCounterVideo, LineCycles;
+	int LineTimerBCycle_old = LineTimerBCycle;
+
+	Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+
 	M68000_WaitState(4);
 
+	/* 0 -> 1, timer B is now counting start of line events (cycle 56+28) */
+	if ( ( ( MFP_AER & ( 1 << 3 ) ) == 0 ) && ( ( IoMem[0xfffa03] & ( 1 << 3 ) ) != 1 ) )
+	{
+		LineTimerBCycle = Video_TimerB_GetPos ( HblCounterVideo );
+
+		LOG_TRACE((TRACE_VIDEO_HBL | TRACE_MFP_WRITE),
+		          "mfp/video AER bit 3 0->1, timer B triggers on start of line,"
+			  " old_pos=%d new_pos=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n",
+		          LineTimerBCycle_old, LineTimerBCycle,
+		          FrameCycles, LineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles);
+	}
+
+	/* 1 -> 0, timer B is now counting end of line events (cycle 376+28) */
+	else if ( ( ( MFP_AER & ( 1 << 3 ) ) != 0 ) && ( ( IoMem[0xfffa03] & ( 1 << 3 ) ) == 0 ) )
+	{
+		LineTimerBCycle = Video_TimerB_GetPos ( HblCounterVideo );
+
+		LOG_TRACE((TRACE_VIDEO_HBL | TRACE_MFP_WRITE),
+		          "mfp/video AER bit 3 1->0, timer B triggers on end of line,"
+			  " old_pos=%d new_pos=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n",
+		          LineTimerBCycle_old, LineTimerBCycle,
+		          FrameCycles, LineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles);
+	}
+
+	/* Timer B position changed, update the next interrupt */
+	if ( LineTimerBCycle_old != LineTimerBCycle )
+		Video_AddInterruptTimerB ( LineTimerBCycle );
+
 	MFP_AER = IoMem[0xfffa03];
 }
 
@@ -1416,12 +1461,12 @@ void MFP_VectorReg_WriteByte(void)
 		}
 	}
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_WRITE ) )
+	if ( LOG_TRACE_LEVEL( TRACE_MFP_WRITE ) )
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp write vector reg fa17=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-			MFP_VR, nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp write vector reg fa17=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
+			MFP_VR, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 	}
 
 }
@@ -1445,7 +1490,7 @@ void MFP_TimerACtrl_WriteByte(void)
 		 * continue from where we left if the timer is restarted later
 		 * without writing to the data register. */
 		if ((new_tacr == 0) && (MFP_TACR >=1) && (MFP_TACR <= 7))
-			MFP_ReadTimerA(TRUE);	/* Store result in 'MFP_TA_MAINCOUNTER' */
+			MFP_ReadTimerA(true);	/* Store result in 'MFP_TA_MAINCOUNTER' */
 
 		MFP_TACR = new_tacr;            /* set to new value before calling MFP_StartTimer */
 		MFP_StartTimerA();              /* start/stop timer depending on control reg */
@@ -1471,7 +1516,7 @@ void MFP_TimerBCtrl_WriteByte(void)
 		 * continue from where we left if the timer is restarted later
 		 * without writing to the data register. */
 		if ((new_tbcr == 0) && (MFP_TBCR >= 1) && (MFP_TBCR <= 7))
-			MFP_ReadTimerB(TRUE);	/* Store result in 'MFP_TB_MAINCOUNTER' */
+			MFP_ReadTimerB(true);	/* Store result in 'MFP_TB_MAINCOUNTER' */
 
 		MFP_TBCR = new_tbcr;            /* set to new value before calling MFP_StartTimer */
 		MFP_StartTimerB();              /* start/stop timer depending on control reg */
@@ -1500,7 +1545,7 @@ void MFP_TimerCDCtrl_WriteByte(void)
 		 * continue from where we left if the timer is restarted later
 		 * without writing to the data register. */
 		if ((new_tcdcr & 0x70) == 0)
-			MFP_ReadTimerC(TRUE);		/* Store result in 'MFP_TC_MAINCOUNTER' */
+			MFP_ReadTimerC(true);		/* Store result in 'MFP_TC_MAINCOUNTER' */
 
 		MFP_TCDCR = ( new_tcdcr & 0x70 ) | ( old_tcdcr & 0x07 );	/* we set TCCR and keep old TDDR in case we need to read it below */
 		MFP_StartTimerC();			/* start/stop timer depending on control reg */
@@ -1532,7 +1577,7 @@ void MFP_TimerCDCtrl_WriteByte(void)
 			if ( new_tcdcr & 0x07 )			/* apply patch only if timer D is being started */
 			{
 				new_tcdcr = IoMem[0xfffa1d] = (IoMem[0xfffa1d] & 0xf0) | 7;
-				bAppliedTimerDPatch = TRUE;
+				bAppliedTimerDPatch = true;
 			}
 		}
 
@@ -1540,7 +1585,7 @@ void MFP_TimerCDCtrl_WriteByte(void)
 		/* of the counter to be able to read it or to continue from where we left if the timer is */
 		/* restarted later without writing to the data register. */
 		if ((new_tcdcr & 0x07) == 0)
-			MFP_ReadTimerD(TRUE);	/* Stores result in 'MFP_TD_MAINCOUNTER' */
+			MFP_ReadTimerD(true);	/* Stores result in 'MFP_TD_MAINCOUNTER' */
 
 		MFP_TCDCR = new_tcdcr;		/* set to new value before calling MFP_StartTimer */
 		MFP_StartTimerD();		/* start/stop timer depending on control reg */
@@ -1560,15 +1605,15 @@ void MFP_TimerAData_WriteByte(void)
 	if (MFP_TACR == 0)                  /* Now check if timer is running - if so do not set */
 	{
 		MFP_TA_MAINCOUNTER = MFP_TADR;  /* Timer is off, store to main counter */
-		TimerACanResume = FALSE;        /* we need to set a new int when timer start */
+		TimerACanResume = false;        /* we need to set a new int when timer start */
 	}
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_WRITE ) )
+	if ( LOG_TRACE_LEVEL( TRACE_MFP_WRITE ) )
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp write data reg A fa1f=0x%x new counter=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-			MFP_TADR, MFP_TA_MAINCOUNTER, nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp write data reg A fa1f=0x%x new counter=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
+			MFP_TADR, MFP_TA_MAINCOUNTER, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 	}
 }
 
@@ -1585,15 +1630,15 @@ void MFP_TimerBData_WriteByte(void)
 	if (MFP_TBCR == 0)                  /* Now check if timer is running - if so do not set */
 	{
 		MFP_TB_MAINCOUNTER = MFP_TBDR;  /* Timer is off, store to main counter */
-		TimerBCanResume = FALSE;        /* we need to set a new int when timer start */
+		TimerBCanResume = false;        /* we need to set a new int when timer start */
 	}
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_WRITE ) )
+	if ( LOG_TRACE_LEVEL( TRACE_MFP_WRITE ) )
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp write data reg B fa21=0x%x new counter=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-			MFP_TBDR, MFP_TB_MAINCOUNTER, nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp write data reg B fa21=0x%x new counter=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
+			MFP_TBDR, MFP_TB_MAINCOUNTER, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 	}
 }
 
@@ -1610,15 +1655,15 @@ void MFP_TimerCData_WriteByte(void)
 	if ((MFP_TCDCR&0x70) == 0)          /* Now check if timer is running - if so do not set */
 	{
 		MFP_TC_MAINCOUNTER = MFP_TCDR;  /* Timer is off, store to main counter */
-		TimerCCanResume = FALSE;        /* we need to set a new int when timer start */
+		TimerCCanResume = false;        /* we need to set a new int when timer start */
 	}
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_WRITE ) )
+	if ( LOG_TRACE_LEVEL( TRACE_MFP_WRITE ) )
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp write data reg C fa23=0x%x new counter=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-			MFP_TCDR, MFP_TC_MAINCOUNTER, nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp write data reg C fa23=0x%x new counter=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
+			MFP_TCDR, MFP_TC_MAINCOUNTER, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 	}
 }
 
@@ -1649,14 +1694,14 @@ void MFP_TimerDData_WriteByte(void)
 	if ((MFP_TCDCR&0x07) == 0)          /* Now check if timer is running - if so do not set */
 	{
 		MFP_TD_MAINCOUNTER = MFP_TDDR;  /* Timer is off, store to main counter */
-		TimerDCanResume = FALSE;        /* we need to set a new int when timer start */
+		TimerDCanResume = false;        /* we need to set a new int when timer start */
 	}
 
-	if ( HATARI_TRACE_LEVEL ( HATARI_TRACE_MFP_WRITE ) )
+	if ( LOG_TRACE_LEVEL( TRACE_MFP_WRITE ) )
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "mfp write data reg D fa25=0x%x new counter=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
-			MFP_TDDR, MFP_TD_MAINCOUNTER, nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("mfp write data reg D fa25=0x%x new counter=0x%x video_cyc=%d %d@%d pc=%x instr_cycle %d\n" ,
+			MFP_TDDR, MFP_TD_MAINCOUNTER, FrameCycles, LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles );
 	}
 }
