@@ -12,12 +12,11 @@ const char Paths_fileid[] = "Hatari paths.c : " __DATE__ " " __TIME__;
 #include <sys/stat.h>
 #include <sys/types.h>
 
-#include "config.h"
 #include "main.h"
 #include "file.h"
 #include "paths.h"
 
-#ifdef WIN32
+#if defined(WIN32) && !defined(mkdir)
 #define mkdir(name,mode) mkdir(name)
 #endif  /* WIN32 */
 
@@ -225,7 +224,11 @@ void Paths_Init(const char *argv0)
 	char *psExecDir;  /* Path string where the hatari executable can be found */
 
 	/* Init working directory string */
-	getcwd(sWorkingDir, FILENAME_MAX);
+	if (getcwd(sWorkingDir, FILENAME_MAX) == NULL)
+	{
+		/* This should never happen... just in case... */
+		strcpy(sWorkingDir, ".");
+	}
 
 	/* Init the user's home directory string */
 	Paths_InitHomeDirs();
