@@ -6,7 +6,7 @@
 
   Screen Snapshots.
 */
-const char ScreenSnapShot_rcsid[] = "Hatari $Id: screenSnapShot.c,v 1.19 2008-11-16 09:42:12 thothy Exp $";
+const char ScreenSnapShot_fileid[] = "Hatari screenSnapShot.c : " __DATE__ " " __TIME__;
 
 #include <SDL.h>
 #include <dirent.h>
@@ -24,7 +24,7 @@ const char ScreenSnapShot_rcsid[] = "Hatari $Id: screenSnapShot.c,v 1.19 2008-11
 #endif
 
 
-bool bRecordingAnimation = FALSE;           /* Recording animation? */
+bool bRecordingAnimation = false;           /* Recording animation? */
 static int nScreenShots = 0;                /* Number of screen shots saved */
 static bool bGrabWhenChange;
 
@@ -224,8 +224,9 @@ png_cleanup:
 
 /*-----------------------------------------------------------------------*/
 /**
- * Save screen shot file with filename 'grab0000.<ext>','grab0001.<ext>'...
- * Whether screen shots are saved as BMP or PNG depends on Hatari configuration.
+ * Save screen shot file with filename like 'grab0000.[png|bmp]',
+ * 'grab0001.[png|bmp]', etc... Whether screen shots are saved as BMP
+ * or PNG depends on Hatari configuration.
  */
 void ScreenSnapShot_SaveScreen(void)
 {
@@ -276,7 +277,7 @@ void ScreenSnapShot_BeginRecording(bool bCaptureChange)
 	bGrabWhenChange = bCaptureChange;
 
 	/* Start animation */
-	bRecordingAnimation = TRUE;
+	bRecordingAnimation = true;
 
 	/* And inform user */
 	Log_AlertDlg(LOG_INFO, "Screenshot recording started.");
@@ -293,7 +294,7 @@ void ScreenSnapShot_EndRecording()
 	if (bRecordingAnimation)
 	{
 		/* Stop animation */
-		bRecordingAnimation = FALSE;
+		bRecordingAnimation = false;
 
 		/* And inform user */
 		Log_AlertDlg(LOG_INFO, "Screenshot recording stopped.");
