@@ -65,7 +65,7 @@
 
 
 
-const char Sound_rcsid[] = "Hatari $Id: sound.c,v 1.53 2008-11-23 11:49:03 npomarede Exp $";
+const char Sound_fileid[] = "Hatari sound.c : " __DATE__ " " __TIME__;
 
 #include <SDL_types.h>
 
@@ -158,10 +158,10 @@ static yms16 *ymout5 = (yms16 *)ymout5_u16;
 /*--------------------------------------------------------------*/
 
 /* Number of generated samples per frame (eg. 44Khz=882) */
-#define SAMPLES_PER_FRAME  ((SoundPlayBackFrequencies[OutputAudioFreqIndex]+35)/nScreenRefreshRate)
+#define SAMPLES_PER_FRAME  ((nAudioFrequency+35)/nScreenRefreshRate)
 
 /* Current sound replay freq (usually 44100 Hz) */
-#define YM_REPLAY_FREQ   (SoundPlayBackFrequencies[OutputAudioFreqIndex])
+#define YM_REPLAY_FREQ   nAudioFrequency
 
 /* YM-2149 clock on Atari ST is 2 MHz */
 #define YM_ATARI_CLOCK                 2000000
@@ -177,7 +177,7 @@ static yms16 *ymout5 = (yms16 *)ymout5_u16;
 
 /* Constants for YM2149_Normalise_5bit_Table */
 #define	YM_OUTPUT_LEVEL			0x7fff		/* amplitude of the final signal (0..65535 if centered, 0..32767 if not) */
-#define YM_OUTPUT_CENTERED		FALSE
+#define YM_OUTPUT_CENTERED		false
 
 
 
@@ -221,7 +221,7 @@ static ymu16	Vol3Voices = 0;				/* volume 0-0x1f for voices having a constant vo
 Uint8		SoundRegs[ 14 ];
 
 int		YmVolumeMixing = YM_LINEAR_MIXING;
-bool		UseLowPassFilter = FALSE;
+bool		UseLowPassFilter = false;
 
 bool		bEnvelopeFreqFlag;			/* Cleared each frame for YM saving */
 
@@ -272,7 +272,7 @@ static void	Sound_GenerateSamples	(void);
 static void	DcAdjuster_Reset(void)
 {
 	int	i;
-	
+
 	for (i=0 ; i<DC_ADJUST_BUFFERLEN ; i++)
 		dc_buffer[i] = 0;
 
@@ -332,7 +332,7 @@ static int	volumetable_get(int i, int j, int k)
 		j = 15;
 	if (k == 16)
 		k = 15;
-  
+
 	return volumetable_original[i + 16 * j + 16 * 16 * k];
 }
 
@@ -394,15 +394,15 @@ static void	interpolate_volumetable(ymu16 *out)
 				i1 = volumetable_get(i, j, k);
 				/* copy value unchanged to new position */
 				volumetable_set(out,i*2, j*2, k*2, i1);
-                
+ 
 				/* interpolate in i direction */
 				i2 = volumetable_get(i + 1, j, k);
 				volumetable_set(out,i*2 + 1, j*2, k*2, volumetable_interpolate(i1, i2));
-                
+
 				/* interpolate in j direction */
 				i2 = volumetable_get(i, j+1, k);
 				volumetable_set(out,i*2, j*2 + 1, k*2, volumetable_interpolate(i1, i2));
-                
+
 				/* interpolate in k direction */
 				i2 = volumetable_get(i, j, k+1);
 				volumetable_set(out,i*2, j*2, k*2+1, volumetable_interpolate(i1, i2));
@@ -410,11 +410,11 @@ static void	interpolate_volumetable(ymu16 *out)
 				/* interpolate in i + j direction */
 				i2 = volumetable_get(i + 1, j + 1, k);
 				volumetable_set(out,i*2 + 1, j*2 + 1, k*2, volumetable_interpolate(i1, i2));
-                
+
 				/* interpolate in i + k direction */
 				i2 = volumetable_get(i + 1, j, k + 1);
 				volumetable_set(out,i*2 + 1, j*2, k*2 + 1, volumetable_interpolate(i1, i2));
-                
+
 				/* interpolate in j + k direction */
 				i2 = volumetable_get(i, j + 1, k + 1);
 				volumetable_set(out,i*2, j*2 + 1, k*2 + 1, volumetable_interpolate(i1, i2));
@@ -465,18 +465,18 @@ static void	YM2149_BuildLinearVolumeTable(ymu16 *out)
  * - out_5bit will contain signed values
  * Possible values are :
  *	Level=65535 and DoCenter=TRUE -> [-32768,32767]
- *	Level=32767 and DoCenter=FALSE -> [0,32767]
+ *	Level=32767 and DoCenter=false -> [0,32767]
  */
 
 static void	YM2149_Normalise_5bit_Table(ymu16 *in_5bit , yms16 *out_5bit, unsigned int Level, bool DoCenter)
 {
 	if ( Level )
 	{
-   		int h;
+		int h;
 		int Max = in_5bit[0x7fff];
 		int Center = Level>>1;
-//fprintf ( stderr , "level %d max %d center %d\n" , Level, Max, Center );
-		
+		//fprintf ( stderr , "level %d max %d center %d\n" , Level, Max, Center );
+
 		/* Change the amplitude of the signal to 'level' : [0,max] -> [0,level] */
 		/* Then optionally center the signal around Level/2 */
 		/* This means we go from sthg like [0,65535] to [-32768, 32767] if Level=65535 and DoCenter=TRUE */
@@ -484,12 +484,12 @@ static void	YM2149_Normalise_5bit_Table(ymu16 *in_5bit , yms16 *out_5bit, unsign
 		{
 			int tmp = in_5bit[h], res;
 			res = tmp * Level / Max;
-			
+
 			if ( DoCenter )
 				res -= Center;
 
 			out_5bit[h] = res;
-//fprintf ( stderr , "h %d in %d out %d\n" , h , tmp , res );	
+			//fprintf ( stderr , "h %d in %d out %d\n" , h , tmp , res );
 		}
 	}
 }
@@ -514,13 +514,14 @@ static void	YM2149_EnvBuild ( void )
 	for ( env=0 ; env<16 ; env++ )				/* 16 possible envelopes */
 		for ( block=0 ; block<3 ; block++ )		/* 3 blocks to define an envelope */
 		{
-			switch ( YmEnvDef[ env ][ block ] ) {
+			switch ( YmEnvDef[ env ][ block ] )
+			{
 				case ENV_GODOWN :	vol=31 ; inc=-1 ; break;
 				case ENV_GOUP :		vol=0  ; inc=1 ; break;
 				case ENV_DOWN :		vol=0  ; inc=0 ; break;
 				case ENV_UP :		vol=31 ; inc=0 ; break;
-			}			
-			
+			}
+
 			for ( i=0 ; i<32 ; i++ )		/* 32 volumes per block */
 			{
 				YmEnvWaves[ env ][ block*32 + i ] = YM_MERGE_VOICE ( vol , vol , vol );
@@ -566,16 +567,16 @@ static void	Ym2149_Init(void)
 static void	Ym2149_Reset(void)
 {
 	int	i;
-	
+
 	for ( i=0 ; i<14 ; i++ )
 		Sound_WriteReg ( i , 0 );
 
 	Sound_WriteReg ( 7 , 0xff );
 
 	currentNoise = 0xffff;
-	
+
 	RndRack = 1;
-	
+
 	envShape = 0;
 	envPos = 0;
 
@@ -593,7 +594,7 @@ static void	Ym2149_Reset(void)
 static ymu32	YM2149_RndCompute(void)
 {
 	ymu32	bit;
-		
+
 	bit = (RndRack&1) ^ ((RndRack>>2)&1);
 	RndRack = (RndRack>>1) | (bit<<16);
 	return (bit ? 0 : 0xffff);
@@ -610,13 +611,14 @@ static ymu32	YM2149_RndCompute(void)
 static ymu32	Ym2149_ToneStepCompute(ymu8 rHigh , ymu8 rLow)
 {
 	int	per;
+	yms64	step;
 
 	per = rHigh&15;
 	per = (per<<8)+rLow;
-	if (per<=5) 
+	if (per <= 5)
 		return 0;
 
-	yms64 step = YM_ATARI_CLOCK;
+	step = YM_ATARI_CLOCK;
 	step <<= (15+16-3);
 	step /= (per * YM_REPLAY_FREQ);
 
@@ -627,12 +629,13 @@ static ymu32	Ym2149_ToneStepCompute(ymu8 rHigh , ymu8 rLow)
 static ymu32	Ym2149_NoiseStepCompute(ymu8 rNoise)
 {
 	int	per;
+	yms64	step;
 
 	per = (rNoise&0x1f);
 	if (per<3)
 		return 0;
 
-	yms64 step = YM_ATARI_CLOCK;
+	step = YM_ATARI_CLOCK;
 	step <<= (16-1-3);
 	step /= (per * YM_REPLAY_FREQ);
 
@@ -660,11 +663,12 @@ static ymu32	Ym2149_NoiseStepCompute(ymu8 rNoise)
 static ymu32	Ym2149_EnvStepCompute(ymu8 rHigh , ymu8 rLow)
 {
 	yms64	per;
+	yms64	step;
 
 	per = rHigh;
 	per = (per<<8)+rLow;
 
-	yms64 step = YM_ATARI_CLOCK;
+	step = YM_ATARI_CLOCK;
 	step <<= 24;
 	if ( per > 0 )
 		step /= (8 * per * YM_REPLAY_FREQ);	/* 0x5ab < step < 0x5ab3f46 at 44.1 kHz */
@@ -727,17 +731,18 @@ static ymsample	YM2149_NextSample(void)
 	posB += stepB;
 	posC += stepC;
 	noisePos += noiseStep;
-	
+
 	envPos += envStep;
 	if ( envPos >= (3*32) << 24 )			/* blocks 0, 1 and 2 were used (envPos 0 to 95) */
 		envPos -= (2*32) << 24;			/* replay/loop blocks 1 and 2 (envPos 32 to 95) */
 
+	DcAdjuster_AddSample(sample);			/* Calculate DC level */
+	sample = sample - DcAdjuster_GetDcLevel();	/* normalize sound level */
 
 	/* Apply low pass filter ? */
 	if ( UseLowPassFilter )
 	{
-		DcAdjuster_AddSample ( sample );	/* normalize sound level */
-		sample = LowPassFilter ( sample - DcAdjuster_GetDcLevel() );
+		sample = LowPassFilter(sample);
 	}
 
 	return sample;
@@ -825,7 +830,7 @@ void	Sound_WriteReg( int reg , Uint8 data )
 				Vol3Voices |= YmVolume4to5[ SoundRegs[8] ];	/* fixed vol ON */
 			}
 			break;
-		
+
 		case 9:
 			SoundRegs[9] = data & 0x1f;
 			if ( data & 0x10 )
@@ -840,7 +845,7 @@ void	Sound_WriteReg( int reg , Uint8 data )
 				Vol3Voices |= ( YmVolume4to5[ SoundRegs[9] ] ) << 5;	/* fixed vol ON */
 			}
 			break;
-		
+
 		case 10:
 			SoundRegs[10] = data & 0x1f;
 			if ( data & 0x10 )
@@ -870,7 +875,7 @@ void	Sound_WriteReg( int reg , Uint8 data )
 			SoundRegs[13] = data & 0xf;
 			envPos = 0;					/* when writing to EnvShape, we must reset the EnvPos */
 			envShape = SoundRegs[13];
-			bEnvelopeFreqFlag = TRUE;			/* used for YmFormat saving */
+			bEnvelopeFreqFlag = true;			/* used for YmFormat saving */
 			break;
 
 	}
@@ -887,7 +892,7 @@ void Sound_Init(void)
 {
 	/* Build volume/env tables, ... */
 	Ym2149_Init();
-	
+
 	Sound_Reset();
 }
 
@@ -907,8 +912,8 @@ void Sound_Reset(void)
 
 	/* Clear cycle counts, buffer index and register '13' flags */
 	Cycles_SetCounter(CYCLES_COUNTER_SOUND, 0);
-	bEnvelopeFreqFlag = FALSE;
-	
+	bEnvelopeFreqFlag = false;
+
 	CompleteSndBufIdx = 0;
 	/* We do not start with 0 here to fake some initial samples: */
 	nGeneratedSamples = SoundBufferSize + SAMPLES_PER_FRAME;
@@ -962,14 +967,14 @@ void Sound_MemorySnapShot_Capture(bool bSave)
 	MemorySnapShot_Store(&envStep, sizeof(envStep));
 	MemorySnapShot_Store(&envPos, sizeof(envPos));
 	MemorySnapShot_Store(&envShape, sizeof(envShape));
-	
+
 	MemorySnapShot_Store(&EnvMask3Voices, sizeof(EnvMask3Voices));
 	MemorySnapShot_Store(&Vol3Voices, sizeof(Vol3Voices));
-	
+
 	MemorySnapShot_Store(SoundRegs, sizeof(SoundRegs));
 
-	MemorySnapShot_Store(&YmVolumeMixing, sizeof(YmVolumeMixing));
-	MemorySnapShot_Store(&UseLowPassFilter, sizeof(UseLowPassFilter));
+	// MemorySnapShot_Store(&YmVolumeMixing, sizeof(YmVolumeMixing));
+	// MemorySnapShot_Store(&UseLowPassFilter, sizeof(UseLowPassFilter));
 }
 
 
@@ -1016,16 +1021,16 @@ static void Sound_GenerateSamples(void)
 {
 	int	i;
 	int	idx;
-	
+
 	if (nSamplesToGenerate <= 0)
 		return;
-	
+
 	for (i = 0; i < nSamplesToGenerate; i++)
 	{
 		idx = (ActiveSndBufIdx + i) % MIXBUFFER_SIZE;
 		MixBuffer[idx][0] = MixBuffer[idx][1] = YM2149_NextSample();
 	}
-	
+
 	DmaSnd_GenerateSamples(ActiveSndBufIdx, nSamplesToGenerate);
 
 	ActiveSndBufIdx = (ActiveSndBufIdx + nSamplesToGenerate) % MIXBUFFER_SIZE;
@@ -1067,7 +1072,7 @@ void Sound_Update_VBL(void)
 	Sound_Update();
 
 	/* Clear write to register '13', used for YM file saving */
-	bEnvelopeFreqFlag = FALSE;
+	bEnvelopeFreqFlag = false;
 }
 
 
@@ -1082,7 +1087,7 @@ bool Sound_BeginRecording(char *pszCaptureFileName)
 	if (!pszCaptureFileName || strlen(pszCaptureFileName) <= 3)
 	{
 		Log_Printf(LOG_ERROR, "Illegal sound recording file name!\n");
-		return FALSE;
+		return false;
 	}
 
 	/* Did specify .YM or .WAV? If neither report error */
@@ -1094,7 +1099,7 @@ bool Sound_BeginRecording(char *pszCaptureFileName)
 	{
 		Log_AlertDlg(LOG_ERROR, "Unknown Sound Recording format.\n"
 		             "Please specify a .YM or .WAV output file.");
-		bRet = FALSE;
+		bRet = false;
 	}
 
 	return bRet;
