@@ -51,12 +51,13 @@
 /*			8 or 4 pixels too late. Calibration was made using a custom program to	*/
 /*			compare the results with a real STF in different cases (fix Froggies	*/
 /*			Over The Fence Main Menu).						*/
-/* 2008/12/21	[NP]	Use BusMode to adjust Cycles_GetCounterOnReadAccess and		*/
-/*			Cycles_GetCounterOnWriteAccess depending on who is owning the	*/
-/*			bus (cpu, blitter).						*/
+/* 2008/12/21	[NP]	Use BusMode to adjust Cycles_GetCounterOnReadAccess and			*/
+/*			Cycles_GetCounterOnWriteAccess depending on who is owning the		*/
+/*			bus (cpu, blitter).							*/
+/* 2009/07/28	[NP]	Use different timings for movem.l and movem.w				*/
 
 
-const char Spec512_rcsid[] = "Hatari $Id: spec512.c,v 1.31 2008-12-14 18:02:03 npomarede Exp $";
+const char Spec512_fileid[] = "Hatari spec512.c : " __DATE__ " " __TIME__;
 
 #include <SDL_byteorder.h>
 
@@ -103,33 +104,35 @@ static const int STRGBPalEndianTable[16] =
 
 /*-----------------------------------------------------------------------*/
 /**
- * Return TRUE if this frame is a Spectrum 512 style image(MUST be low res/non-mix)
+ * Return true if this frame is a Spectrum 512 style image (MUST be low
+ * res/non-mix).
  */
 bool Spec512_IsImage(void)
 {
 	/* Normal Low res screen? */
 	if (STRes == ST_LOW_RES && bIsSpec512Display)
-		return TRUE;
+		return true;
 
-	return FALSE;
+	return false;
 }
 
 
 /*-----------------------------------------------------------------------*/
 /**
- * We store every palette access in a table to perform Spectrum 512 colour effects
- * This is cleared on each VBL
+ * We store every palette access in a table to perform Spectrum 512 color
+ * effects. This is cleared on each VBL.
  */
 void Spec512_StartVBL(void)
 {
 	/* Clear number of cycle palettes on each frame */
 	memset(nCyclePalettes, 0x0, sizeof(nCyclePalettes));
 
-	/* Clear number of times accessed on entry in palette (used to check if is true Spectrum 512 image) */
+	/* Clear number of times accessed on entry in palette (used to check if
+	 * it is true Spectrum 512 image) */
 	nPalettesAccesses = 0;
 
 	/* Set as not Spectrum 512 displayed image */
-	bIsSpec512Display = FALSE;
+	bIsSpec512Display = false;
 }
 
 
@@ -166,26 +169,35 @@ void Spec512_StoreCyclePalette(Uint16 col, Uint32 addr)
 #else
 		if ( OpcodeFamily == i_MVMLE )
 		{
-			FrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO) + 8;
+//			FrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO) + 8;
+			FrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO)
+			              + (CurrentInstrCycles & ~3);
+			if (nIoMemAccessSize == SIZE_LONG)	/* long access */
+				FrameCycles -= 0;
+			else					/* word access */
+				FrameCycles -= 4;
+		}
+		else
+		{
+			FrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO)
+			              + (CurrentInstrCycles & ~3);
+			if (nIoMemAccessSize == SIZE_LONG)	/* long access */
+				FrameCycles -= 8;
+			else					/* word/byte access */
+				FrameCycles -= 4;
 		}
-
-		else if ( nIoMemAccessSize == SIZE_LONG )	/* long access */
-			FrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO) + CurrentInstrCycles - 8;
-		else						/* word/byte access */
-			FrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO) + CurrentInstrCycles - 4;
 #endif
 	}
 
 
 	/* Find scan line we are currently on and get index into cycle-palette table */
-	ScanLine = FrameCycles / nCyclesPerLine;
+	Video_ConvertPosition ( FrameCycles , &ScanLine , &nHorPos );	
 
 	if (ScanLine > MAX_SCANLINES_PER_FRAME)
 		return;
 
 	pTmpCyclePalette = &CyclePalettes[ (ScanLine*MAX_CYCLEPALETTES_PERLINE) + nCyclePalettes[ScanLine] ];
 
-	nHorPos = FrameCycles % nCyclesPerLine;
 
 	/* Do we have a previous entry at the same cycles? If so, 68000 have used a 'move.l' instruction so stagger writes */
 	if (nCyclePalettes[ScanLine] > 0)
@@ -208,12 +220,14 @@ void Spec512_StoreCyclePalette(Uint16 col, Uint32 addr)
 	pTmpCyclePalette->Colour = CycleColour;           /* Store ST/STe color RGB */
 	pTmpCyclePalette->Index = CycleColourIndex;       /* And index (0...15) */
 
-	if ( 0 && HATARI_TRACE_LEVEL ( HATARI_TRACE_VIDEO_COLOR ) )
+	if ( 0 && LOG_TRACE_LEVEL(TRACE_VIDEO_COLOR))
 	{
-		int nFrameCycles = Cycles_GetCounter(CYCLES_COUNTER_VIDEO);;
-		int nLineCycles = nFrameCycles % nCyclesPerLine;
-		HATARI_TRACE_PRINT ( "spec store col line %d cyc=%d col=%x idx=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n" , ScanLine , nHorPos , CycleColour , CycleColourIndex ,
-		                     nFrameCycles, nLineCycles, nHBL, M68000_GetPC(), CurrentInstrCycles );
+		int FrameCycles, HblCounterVideo, LineCycles;
+
+		Video_GetPosition ( &FrameCycles , &HblCounterVideo , &LineCycles );
+		LOG_TRACE_PRINT("spec store col line %d cyc=%d col=%x idx=%d video_cyc=%d %d@%d pc=%x instr_cyc=%d\n",
+				ScanLine, nHorPos, CycleColour, CycleColourIndex, FrameCycles,
+				LineCycles, HblCounterVideo, M68000_GetPC(), CurrentInstrCycles);
 	}
 
 	/* Increment count (this can never overflow as you cannot write to the palette more than 'MAX_CYCLEPALETTES_PERLINE-1' times per scanline) */
@@ -224,7 +238,7 @@ void Spec512_StoreCyclePalette(Uint16 col, Uint32 addr)
 	nPalettesAccesses++;
 	if (nPalettesAccesses >= ConfigureParams.Screen.nSpec512Threshold)
 	{
-		bIsSpec512Display = TRUE;
+		bIsSpec512Display = true;
 	}
 }
 
