@@ -5,7 +5,7 @@
   your option any later version. Read the file gpl.txt for details.
 
   Code to draw statusbar area, floppy leds etc.
-  
+
   Use like this:
   - Before screen surface is (re-)created Statusbar_SetHeight()
     has to be called with the new screen height. Add the returned
@@ -25,19 +25,12 @@
   - If other information shown by Statusbar (TOS version etc) changes,
     call Statusbar_UpdateInfo()
 
-  CHANGES
-  2008-10-25:
-  - In fullscreen video mode may not match the requested size.
-    Disable statusbar if smaller, re-calculate vars if larger.
-  2008-10-26:
-  - Fix message expire & timings
-
   TODO:
   - re-calculate colors on each update to make sure they're
     correct in Falcon & TT 8-bit palette modes?
   - call Statusbar_AddMessage() from log.c?
 */
-const char statusbar_rcsid[] = "$Id: statusbar.c,v 1.15 2008-10-26 22:39:50 eerot Exp $";
+const char Statusbar_fileid[] = "Hatari statusbar.c : " __DATE__ " " __TIME__;
 
 #include <assert.h>
 #include "main.h"
@@ -127,7 +120,7 @@ int Statusbar_SetHeight(int width, int height)
 		/* Should check the same thing as SDLGui_SetScreen()
 		 * does to decide the font size.
 		 */
-		if (width >= 640 && height >= 400) {
+		if (width >= 640 && height >= (400-24)) {
 			StatusbarHeight = 24;
 		} else {
 			StatusbarHeight = 12;
@@ -156,7 +149,7 @@ void Statusbar_EnableHDLed(void)
 {
 	/* leds are shown for 1/2 sec after enabling */
 	Led[DRIVE_LED_HD].expire = SDL_GetTicks() + 1000/2;
-	Led[DRIVE_LED_HD].state = TRUE;
+	Led[DRIVE_LED_HD].state = true;
 }
 
 /*-----------------------------------------------------------------------*/
@@ -221,7 +214,7 @@ void Statusbar_Init(SDL_Surface *surf)
 
 	/* disable leds */
 	for (i = 0; i < MAX_DRIVE_LEDS; i++) {
-		Led[i].state = Led[i].oldstate = FALSE;
+		Led[i].state = Led[i].oldstate = false;
 		Led[i].expire = 0;
 	}
 	Statusbar_OverlayInit(surf);
@@ -299,7 +292,7 @@ void Statusbar_Init(SDL_Surface *surf)
 	MessageRect.w = MAX_MESSAGE_LEN * fontw;
 	MessageRect.h = fonth;
 	for (item = MessageList; item; item = item->next) {
-		item->shown = FALSE;
+		item->shown = false;
 	}
 
 	/* draw recording led box */
@@ -309,7 +302,7 @@ void Statusbar_Init(SDL_Surface *surf)
 	SDLGui_Text(ledbox.x - 4*fontw - fontw/2, MessageRect.y, "REC:");
 	SDL_FillRect(surf, &ledbox, LedColorBg);
 	SDL_FillRect(surf, &RecLedRect, RecColorOff);
-	bOldRecording = FALSE;
+	bOldRecording = false;
 
 	/* and blit statusbar on screen */
 	SDL_UpdateRects(surf, 1, &sbarbox);
@@ -345,7 +338,7 @@ void Statusbar_AddMessage(const char *msg, Uint32 msecs)
 		/* show items by default for 2.5 secs */
 		item->timeout = 2500;
 	}
-	item->shown = FALSE;
+	item->shown = false;
 }
 
 /*-----------------------------------------------------------------------*/
@@ -413,7 +406,7 @@ void Statusbar_UpdateInfo(void)
 	*end = '\0';
 	assert(end - DefaultMessage.msg < MAX_MESSAGE_LEN);
 	DEBUGPRINT(("Set default message: '%s'\n", DefaultMessage.msg));
-	DefaultMessage.shown = FALSE;
+	DefaultMessage.shown = false;
 }
 
 /*-----------------------------------------------------------------------*/
@@ -456,7 +449,7 @@ static void Statusbar_ShowMessage(SDL_Surface *surf, Uint32 ticks)
 		free(MessageList);
 		MessageList = next;
 		/* make sure next message gets shown */
-		MessageList->shown = FALSE;
+		MessageList->shown = false;
 	}
 	if (!MessageList->shown) {
 		/* not shown yet, show */
@@ -464,7 +457,7 @@ static void Statusbar_ShowMessage(SDL_Surface *surf, Uint32 ticks)
 		if (MessageList->timeout && !MessageList->expire) {
 			MessageList->expire = ticks + MessageList->timeout;
 		}
-		MessageList->shown = TRUE;
+		MessageList->shown = true;
 	}
 }
 
@@ -475,7 +468,8 @@ static void Statusbar_ShowMessage(SDL_Surface *surf, Uint32 ticks)
  */
 void Statusbar_OverlayBackup(SDL_Surface *surf)
 {
-	if (StatusbarHeight && ConfigureParams.Screen.bShowStatusbar) {
+	if ((StatusbarHeight && ConfigureParams.Screen.bShowStatusbar)
+	    || !ConfigureParams.Screen.bShowDriveLed) {
 		/* overlay not used with statusbar */
 		return;
 	}
@@ -500,7 +494,8 @@ void Statusbar_OverlayBackup(SDL_Surface *surf)
  */
 void Statusbar_OverlayRestore(SDL_Surface *surf)
 {
-	if (StatusbarHeight && ConfigureParams.Screen.bShowStatusbar) {
+	if ((StatusbarHeight && ConfigureParams.Screen.bShowStatusbar)
+	    || !ConfigureParams.Screen.bShowDriveLed) {
 		/* overlay not used with statusbar */
 		return;
 	}
@@ -551,7 +546,7 @@ static void Statusbar_OverlayDraw(SDL_Surface *surf)
 	for (i = 0; i < MAX_DRIVE_LEDS; i++) {
 		if (Led[i].state) {
 			if (Led[i].expire && Led[i].expire < currentticks) {
-				Led[i].state = FALSE;
+				Led[i].state = false;
 				continue;
 			}
 			Statusbar_OverlayDrawLed(surf, LedColorOn);
@@ -602,7 +597,7 @@ void Statusbar_Update(SDL_Surface *surf)
 	currentticks = SDL_GetTicks();
 	for (i = 0; i < MAX_DRIVE_LEDS; i++) {
 		if (Led[i].expire && Led[i].expire < currentticks) {
-			Led[i].state = FALSE;
+			Led[i].state = false;
 		}
 		if (Led[i].state == Led[i].oldstate) {
 			continue;
@@ -621,7 +616,11 @@ void Statusbar_Update(SDL_Surface *surf)
 	Statusbar_ShowMessage(surf, currentticks);
 
 	if (nFrameSkips != nOldFrameSkips) {
-		char fscount[2] = { '0' + nFrameSkips, '\0' };
+		char fscount[2] = { '\0', '\0' };
+		if (nFrameSkips < 10)
+			fscount[0] = '0' + nFrameSkips;
+		else
+			fscount[0] = 'X';
 		SDL_FillRect(surf, &FrameSkipsRect, GrayBg);
 		SDLGui_Text(FrameSkipsRect.x, FrameSkipsRect.y, fscount);
 		SDL_UpdateRects(surf, 1, &FrameSkipsRect);
